@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS><TS version="2.0">
 <context>
     <name>AbortedByUserError</name>
     <message>
@@ -157,7 +157,7 @@
 <context>
     <name>DocumentationDialog</name>
     <message>
-        <location filename="src/openteacher.py" line="343"/>
+        <location filename="src/openteacher.py" line="356"/>
         <source>Documentation</source>
         <translation>Dokumentation</translation>
     </message>
@@ -628,12 +628,12 @@
     <message>
         <location filename="ui/openteacher.ui" line="294"/>
         <source>Click here to remove the selected row(s) from the word list table.</source>
-        <translation type="unfinished"></translation>
+        <translation>Klicken Sie hier, um die ausgewählte Zeile (n) aus der Wortliste Tabelle zu entfernen.</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="628"/>
         <source>Think answer</source>
-        <translation type="unfinished"></translation>
+        <translation>Antwort ausdenken</translation>
     </message>
 </context>
 <context>
@@ -665,7 +665,7 @@
     <message>
         <location filename="src/errors.py" line="75"/>
         <source>Please fill in the wordlist title, question language and answer language first. Then try again.</source>
-        <translation>Zuerst den Name des Wortregisters, die Sprache der Fragen und der Antworten eingeben. Anschließend bitte erneut versuchen.</translation>
+        <translation>Bitte zuerst den Namen der Wortliste sowie die Sprache der Fragen und Antworten eingeben. Versuchen Sie es danach erneut.</translation>
     </message>
 </context>
 <context>
@@ -673,203 +673,203 @@
     <message>
         <location filename="src/errors.py" line="51"/>
         <source>Could not open file. Please check that you have permission to read this file.</source>
-        <translation>Kann die Datei nicht öffnen. Bitte überprüfen Sie, ob Sie die Berechtigung zum Lesen der Datei haben.</translation>
+        <translation>Die Datei kann nicht geöffnet werden. Bitte überprüfen Sie, ob Sie die Berechtigung zum Lesen der Datei haben.</translation>
     </message>
 </context>
 <context>
     <name>OpenTeacher</name>
     <message>
-        <location filename="src/openteacher.py" line="207"/>
+        <location filename="src/openteacher.py" line="220"/>
         <source>Code</source>
         <translation>Code</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="212"/>
+        <location filename="src/openteacher.py" line="225"/>
         <source>Localisation</source>
         <translation>Lokalisierung</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="306"/>
+        <location filename="src/openteacher.py" line="319"/>
         <source>License</source>
         <translation>Lizenz</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1233"/>
+        <location filename="src/openteacher.py" line="1250"/>
         <source>No selection was detected.</source>
         <translation>Es wurde nichts gewählt.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1507"/>
+        <location filename="src/openteacher.py" line="1530"/>
         <source>Correct answer</source>
         <translation>Richtige Antwort</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1593"/>
+        <location filename="src/openteacher.py" line="1625"/>
         <source>Translation: </source>
         <translation>Übersetzung:</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1602"/>
+        <location filename="src/openteacher.py" line="1634"/>
         <source>Think about the answer, and press the &apos;View answer&apos; button when you&apos;re done.</source>
-        <translation>Denken Sie nach über die Antwort und drücke auf die &quot;Antwort anzeigen&quot;-Taste wenn Sie fertig sind.</translation>
+        <translation>Denken Sie über die Antwort nach und drücken Sie auf den Knopf »Antwort anzeigen«, wenn Sie bereit sind.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1677"/>
+        <location filename="src/openteacher.py" line="1733"/>
         <source>Hint:</source>
         <translation>Tipp:</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1670"/>
+        <location filename="src/openteacher.py" line="1726"/>
         <source>Click the button to start.</source>
         <translation>Klicken sie auf den Knopf um zu starten.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1732"/>
+        <location filename="src/openteacher.py" line="1788"/>
         <source>Test completed!</source>
         <translation>Prüfung vollendet!</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1732"/>
+        <location filename="src/openteacher.py" line="1788"/>
         <source>Test completed! Your note:</source>
         <translation>Prüfung vollendet! Ihre Note:</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1884"/>
+        <location filename="src/openteacher.py" line="1940"/>
         <source>Message</source>
         <translation>Bericht</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1884"/>
+        <location filename="src/openteacher.py" line="1940"/>
         <source>Do you want to save changes?</source>
         <translation>Möchten Sie die Änderungen speichern?</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1904"/>
+        <location filename="src/openteacher.py" line="1960"/>
         <source>Exit lesson</source>
         <translation>Lektion beenden.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1904"/>
+        <location filename="src/openteacher.py" line="1960"/>
         <source>Are you sure you want to stop the lesson?</source>
         <translation>Wollen Sie die Lektion wirklich beenden?</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1948"/>
+        <location filename="src/openteacher.py" line="2004"/>
         <source>Supported</source>
         <translation>Unterstützt</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2027"/>
+        <location filename="src/openteacher.py" line="2083"/>
         <source>Plain text</source>
         <translation>Einfacher Text</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2042"/>
+        <location filename="src/openteacher.py" line="2098"/>
         <source>Save...</source>
         <translation>Speichern...</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2184"/>
+        <location filename="src/openteacher.py" line="2240"/>
         <source>Print Document</source>
         <translation>Dokument drucken</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2236"/>
+        <location filename="src/openteacher.py" line="2292"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="254"/>
+        <location filename="src/openteacher.py" line="267"/>
         <source>OpenTeacher authors</source>
         <translation>OpenTeacher Autoren</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1194"/>
+        <location filename="src/openteacher.py" line="1211"/>
         <source>The word(s) were entered successfully.</source>
         <translation>Das Wort/die Wörter ist/sind erfolgreich eingegeben.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1230"/>
+        <location filename="src/openteacher.py" line="1247"/>
         <source>The word(s) were removed successfully.</source>
         <translation>Das Wort/die Wörter ist/sind erfolgreich entfernt.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1832"/>
+        <location filename="src/openteacher.py" line="1888"/>
         <source>The wordlist from WRTS was imported successfully.</source>
         <translation>Die WRTS- Wörterliste ist erfolgreich importiert worden.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1862"/>
+        <location filename="src/openteacher.py" line="1918"/>
         <source>Export successful</source>
         <translation>Export wurde erfolgreich abgeschlossen</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1863"/>
+        <location filename="src/openteacher.py" line="1919"/>
         <source>Word list exported to WRTS.</source>
         <translation>Die Wörtertabelle wurde nach WRTS exportiert.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1938"/>
+        <location filename="src/openteacher.py" line="1994"/>
         <source>New file created.</source>
         <translation>Eine neue Datei ist erstellt.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1966"/>
+        <location filename="src/openteacher.py" line="2022"/>
         <source>The selected file was opened successfully.</source>
         <translation>Die gewählte Datei ist erfolgreich geöffnet.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2109"/>
+        <location filename="src/openteacher.py" line="2165"/>
         <source>File saved.</source>
         <translation>Die Datei ist gespeichert.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2190"/>
+        <location filename="src/openteacher.py" line="2246"/>
         <source>The file was printed successfully.</source>
         <translation>Das Dokument ist erfolgreich gedruckt.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="254"/>
+        <location filename="src/openteacher.py" line="267"/>
         <source>Project website</source>
         <translation>Webseite des Projekts</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="251"/>
+        <location filename="src/openteacher.py" line="264"/>
         <source>OpenTeacher helps you learn a foreign language vocabulary.</source>
         <translation>OpenTeacher hilft beim lernen von Vokabeln anderer Sprachen.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>een = one</source>
         <translation>eins = one</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>twee = two</source>
         <translation>Zwei = two</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>drie = three</source>
         <translation>Drei = three</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>Warning</source>
         <translation>Achtung</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>This credentials are saved in plain text on your harddrive.</source>
         <translation>Diese Leistungen/Resultate sind unverschlüsselt auf ihrer Festplatte gespeichert.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>Don&apos;t use this function on a public computer!</source>
         <translation>Bitte nutzen Sie diese Funktion nicht auf öffentlichen Rechnern!</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1948"/>
+        <location filename="src/openteacher.py" line="2004"/>
         <source>Open...</source>
         <translation>Öffne...</translation>
     </message>
@@ -885,72 +885,72 @@
 <context>
     <name>QDialogButtonBox</name>
     <message>
-        <location filename="src/openteacher.py" line="188"/>
+        <location filename="src/openteacher.py" line="201"/>
         <source>Close without Saving</source>
         <translation>Schließen ohne zu speichern</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="175"/>
+        <location filename="src/openteacher.py" line="188"/>
         <source>&amp;OK</source>
         <translation>&amp;Ok</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="177"/>
+        <location filename="src/openteacher.py" line="190"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Abbruch</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="183"/>
+        <location filename="src/openteacher.py" line="196"/>
         <source>&amp;Save</source>
         <translation>&amp;Speichern</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="179"/>
+        <location filename="src/openteacher.py" line="192"/>
         <source>&amp;Yes</source>
         <translation>&amp;Ja</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="180"/>
+        <location filename="src/openteacher.py" line="193"/>
         <source>&amp;No</source>
         <translation>&amp;Nein</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="174"/>
+        <location filename="src/openteacher.py" line="187"/>
         <source>OK</source>
         <translation>Ok</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="176"/>
+        <location filename="src/openteacher.py" line="189"/>
         <source>Cancel</source>
         <translation>Abbrechen</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="182"/>
+        <location filename="src/openteacher.py" line="195"/>
         <source>Save</source>
         <translation>Speichern</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="184"/>
+        <location filename="src/openteacher.py" line="197"/>
         <source>Open</source>
         <translation>Öffnen</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="185"/>
+        <location filename="src/openteacher.py" line="198"/>
         <source>Close</source>
         <translation>Schließen</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="186"/>
+        <location filename="src/openteacher.py" line="199"/>
         <source>&amp;Close</source>
         <translation>&amp;Schließen</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="189"/>
+        <location filename="src/openteacher.py" line="202"/>
         <source>Don&apos;t save</source>
         <translation>Nicht speichern</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="190"/>
+        <location filename="src/openteacher.py" line="203"/>
         <source>Discard</source>
         <translation>Verwerfen</translation>
     </message>
@@ -958,22 +958,22 @@
 <context>
     <name>QShortcut</name>
     <message>
-        <location filename="src/openteacher.py" line="193"/>
+        <location filename="src/openteacher.py" line="206"/>
         <source>Ctrl</source>
         <translation>Strg</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="194"/>
+        <location filename="src/openteacher.py" line="207"/>
         <source>Return</source>
         <translation>Fortfahren</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="195"/>
+        <location filename="src/openteacher.py" line="208"/>
         <source>Del</source>
         <translation>Entf</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="196"/>
+        <location filename="src/openteacher.py" line="209"/>
         <source>Shift</source>
         <translation>Umschalt</translation>
     </message>
@@ -989,22 +989,22 @@
 <context>
     <name>Settings</name>
     <message>
-        <location filename="src/openteacher.py" line="513"/>
+        <location filename="src/openteacher.py" line="526"/>
         <source>Restart please</source>
         <translation>Neustarten bitte</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="484"/>
+        <location filename="src/openteacher.py" line="497"/>
         <source>Connection to WRTS failed</source>
         <translation>Verbindung mit WRTS fehlgeschlagen.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="487"/>
+        <location filename="src/openteacher.py" line="500"/>
         <source>Connection to WRTS succeeded</source>
         <translation>Verbindung mit WRTS hergestelt.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="513"/>
+        <location filename="src/openteacher.py" line="526"/>
         <source>You changed the language. In order to use the newly selected language, you need to restart OpenTeacher.</source>
         <translation>Sie haben die Sprache geändert. Bitte  OpenTeacher neu starten, um die neue Sprache nutzen zu können.</translation>
     </message>
@@ -1012,47 +1012,47 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="src/openteacher.py" line="398"/>
+        <location filename="src/openteacher.py" line="411"/>
         <source>Make your choice</source>
         <translation>Bitte wähle eine Option</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="399"/>
+        <location filename="src/openteacher.py" line="412"/>
         <source>System default</source>
         <translation>Systemvorgabe</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="447"/>
+        <location filename="src/openteacher.py" line="460"/>
         <source>Make your choice (all examples are good to bad)</source>
         <translation>Bitte, wählen (alle Beispielen sind gut zu schlecht)</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="448"/>
+        <location filename="src/openteacher.py" line="461"/>
         <source>Percents</source>
         <translation>Prozente</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="449"/>
+        <location filename="src/openteacher.py" line="462"/>
         <source>Dutch</source>
         <translation>Niederländisch</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="450"/>
+        <location filename="src/openteacher.py" line="463"/>
         <source>American</source>
         <translation>Amerikanisch</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="451"/>
+        <location filename="src/openteacher.py" line="464"/>
         <source>German</source>
         <translation>Deutsch</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="452"/>
+        <location filename="src/openteacher.py" line="465"/>
         <source>French</source>
         <translation>Französisch</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="453"/>
+        <location filename="src/openteacher.py" line="466"/>
         <source>ECTS</source>
         <translation>ECTS</translation>
     </message>
@@ -1076,22 +1076,22 @@
 <context>
     <name>WordListTableModel</name>
     <message>
-        <location filename="src/openteacher.py" line="648"/>
+        <location filename="src/openteacher.py" line="661"/>
         <source>Question</source>
         <translation>Frage</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="649"/>
+        <location filename="src/openteacher.py" line="662"/>
         <source>Answer</source>
         <translation>Antwort</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="650"/>
+        <location filename="src/openteacher.py" line="663"/>
         <source>Second Answer (optional)</source>
         <translation>Zweites Antwort (Option)</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="651"/>
+        <location filename="src/openteacher.py" line="664"/>
         <source>Errors</source>
         <translation>Fehler</translation>
     </message>
