@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS><TS version="2.0">
 <context>
     <name>AbortedByUserError</name>
     <message>
@@ -157,7 +157,7 @@
 <context>
     <name>DocumentationDialog</name>
     <message>
-        <location filename="src/openteacher.py" line="343"/>
+        <location filename="src/openteacher.py" line="356"/>
         <source>Documentation</source>
         <translation>Documentation</translation>
     </message>
@@ -628,12 +628,12 @@
     <message>
         <location filename="ui/openteacher.ui" line="294"/>
         <source>Click here to remove the selected row(s) from the word list table.</source>
-        <translation type="unfinished"></translation>
+        <translation>Click here to remove the selected row(s) from the word list table.</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="628"/>
         <source>Think answer</source>
-        <translation type="unfinished"></translation>
+        <translation>Think answer</translation>
     </message>
 </context>
 <context>
@@ -679,197 +679,197 @@
 <context>
     <name>OpenTeacher</name>
     <message>
-        <location filename="src/openteacher.py" line="207"/>
+        <location filename="src/openteacher.py" line="220"/>
         <source>Code</source>
         <translation>Code</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="212"/>
+        <location filename="src/openteacher.py" line="225"/>
         <source>Localisation</source>
         <translation>Localisation</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="306"/>
+        <location filename="src/openteacher.py" line="319"/>
         <source>License</source>
         <translation>License</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1233"/>
+        <location filename="src/openteacher.py" line="1250"/>
         <source>No selection was detected.</source>
         <translation>No selection was detected.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1507"/>
+        <location filename="src/openteacher.py" line="1530"/>
         <source>Correct answer</source>
         <translation>Correct answer</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1593"/>
+        <location filename="src/openteacher.py" line="1625"/>
         <source>Translation: </source>
         <translation>Translation:</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1602"/>
+        <location filename="src/openteacher.py" line="1634"/>
         <source>Think about the answer, and press the &apos;View answer&apos; button when you&apos;re done.</source>
         <translation>Think about the answer, and press the &apos;View answer&apos; button when you&apos;re done.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1677"/>
+        <location filename="src/openteacher.py" line="1733"/>
         <source>Hint:</source>
         <translation>Hint:</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1670"/>
+        <location filename="src/openteacher.py" line="1726"/>
         <source>Click the button to start.</source>
         <translation>Click the button to start.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1732"/>
+        <location filename="src/openteacher.py" line="1788"/>
         <source>Test completed!</source>
         <translation>Test completed!</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1732"/>
+        <location filename="src/openteacher.py" line="1788"/>
         <source>Test completed! Your note:</source>
         <translation>Test completed! Your note:</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1884"/>
+        <location filename="src/openteacher.py" line="1940"/>
         <source>Message</source>
         <translation>Message</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1884"/>
+        <location filename="src/openteacher.py" line="1940"/>
         <source>Do you want to save changes?</source>
         <translation>Do you want to save changes?</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1904"/>
+        <location filename="src/openteacher.py" line="1960"/>
         <source>Exit lesson</source>
         <translation>Exit lesson</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1904"/>
+        <location filename="src/openteacher.py" line="1960"/>
         <source>Are you sure you want to stop the lesson?</source>
         <translation>Are you sure you want to stop the lesson?</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1948"/>
+        <location filename="src/openteacher.py" line="2004"/>
         <source>Supported</source>
         <translation>Supported</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2027"/>
+        <location filename="src/openteacher.py" line="2083"/>
         <source>Plain text</source>
         <translation>Plain text</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2042"/>
+        <location filename="src/openteacher.py" line="2098"/>
         <source>Save...</source>
         <translation>Save...</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2184"/>
+        <location filename="src/openteacher.py" line="2240"/>
         <source>Print Document</source>
         <translation>Print Document</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2236"/>
+        <location filename="src/openteacher.py" line="2292"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="254"/>
+        <location filename="src/openteacher.py" line="267"/>
         <source>OpenTeacher authors</source>
         <translation>OpenTeacher authors</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1194"/>
+        <location filename="src/openteacher.py" line="1211"/>
         <source>The word(s) were entered successfully.</source>
         <translation>The word(s) were entered successfully.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1230"/>
+        <location filename="src/openteacher.py" line="1247"/>
         <source>The word(s) were removed successfully.</source>
         <translation>The word(s) were removed successfully.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1832"/>
+        <location filename="src/openteacher.py" line="1888"/>
         <source>The wordlist from WRTS was imported successfully.</source>
         <translation>The word list from WRTS was imported successfully.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1862"/>
+        <location filename="src/openteacher.py" line="1918"/>
         <source>Export successful</source>
         <translation>Export successful</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1863"/>
+        <location filename="src/openteacher.py" line="1919"/>
         <source>Word list exported to WRTS.</source>
         <translation>Word list exported to WRTS.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1938"/>
+        <location filename="src/openteacher.py" line="1994"/>
         <source>New file created.</source>
         <translation>New file created.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1966"/>
+        <location filename="src/openteacher.py" line="2022"/>
         <source>The selected file was opened successfully.</source>
         <translation>The selected file was opened successfully.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2109"/>
+        <location filename="src/openteacher.py" line="2165"/>
         <source>File saved.</source>
         <translation>File saved.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2190"/>
+        <location filename="src/openteacher.py" line="2246"/>
         <source>The file was printed successfully.</source>
         <translation>The file was printed successfully.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="254"/>
+        <location filename="src/openteacher.py" line="267"/>
         <source>Project website</source>
         <translation>Project website</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="251"/>
+        <location filename="src/openteacher.py" line="264"/>
         <source>OpenTeacher helps you learn a foreign language vocabulary.</source>
         <translation>OpenTeacher helps you learn a foreign language vocabulary.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>een = one</source>
         <translation>een = one</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>twee = two</source>
         <translation>twee = two</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>drie = three</source>
         <translation>drie = three</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>Warning</source>
         <translation>Warning</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>This credentials are saved in plain text on your harddrive.</source>
         <translation>This credentials are saved in plain text on your hard drive.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>Don&apos;t use this function on a public computer!</source>
         <translation>Don&apos;t use this function on a public computer!</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1948"/>
+        <location filename="src/openteacher.py" line="2004"/>
         <source>Open...</source>
         <translation>Open...</translation>
     </message>
@@ -885,72 +885,72 @@
 <context>
     <name>QDialogButtonBox</name>
     <message>
-        <location filename="src/openteacher.py" line="188"/>
+        <location filename="src/openteacher.py" line="201"/>
         <source>Close without Saving</source>
         <translation>Close without Saving</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="175"/>
+        <location filename="src/openteacher.py" line="188"/>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="177"/>
+        <location filename="src/openteacher.py" line="190"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Cancel</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="183"/>
+        <location filename="src/openteacher.py" line="196"/>
         <source>&amp;Save</source>
         <translation>&amp;Save</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="179"/>
+        <location filename="src/openteacher.py" line="192"/>
         <source>&amp;Yes</source>
         <translation>&amp;Yes</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="180"/>
+        <location filename="src/openteacher.py" line="193"/>
         <source>&amp;No</source>
         <translation>&amp;No</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="174"/>
+        <location filename="src/openteacher.py" line="187"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="176"/>
+        <location filename="src/openteacher.py" line="189"/>
         <source>Cancel</source>
         <translation>Cancel</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="182"/>
+        <location filename="src/openteacher.py" line="195"/>
         <source>Save</source>
         <translation>Save</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="184"/>
+        <location filename="src/openteacher.py" line="197"/>
         <source>Open</source>
         <translation>Open</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="185"/>
+        <location filename="src/openteacher.py" line="198"/>
         <source>Close</source>
         <translation>Close</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="186"/>
+        <location filename="src/openteacher.py" line="199"/>
         <source>&amp;Close</source>
         <translation>&amp;Close</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="189"/>
+        <location filename="src/openteacher.py" line="202"/>
         <source>Don&apos;t save</source>
         <translation>Don&apos;t save</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="190"/>
+        <location filename="src/openteacher.py" line="203"/>
         <source>Discard</source>
         <translation>Discard</translation>
     </message>
@@ -958,22 +958,22 @@
 <context>
     <name>QShortcut</name>
     <message>
-        <location filename="src/openteacher.py" line="193"/>
+        <location filename="src/openteacher.py" line="206"/>
         <source>Ctrl</source>
         <translation>Ctrl</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="194"/>
+        <location filename="src/openteacher.py" line="207"/>
         <source>Return</source>
         <translation>Return</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="195"/>
+        <location filename="src/openteacher.py" line="208"/>
         <source>Del</source>
         <translation>Del</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="196"/>
+        <location filename="src/openteacher.py" line="209"/>
         <source>Shift</source>
         <translation>Shift</translation>
     </message>
@@ -989,22 +989,22 @@
 <context>
     <name>Settings</name>
     <message>
-        <location filename="src/openteacher.py" line="513"/>
+        <location filename="src/openteacher.py" line="526"/>
         <source>Restart please</source>
         <translation>Restart please</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="484"/>
+        <location filename="src/openteacher.py" line="497"/>
         <source>Connection to WRTS failed</source>
         <translation>Connection to WRTS failed</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="487"/>
+        <location filename="src/openteacher.py" line="500"/>
         <source>Connection to WRTS succeeded</source>
         <translation>Connection to WRTS succeeded</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="513"/>
+        <location filename="src/openteacher.py" line="526"/>
         <source>You changed the language. In order to use the newly selected language, you need to restart OpenTeacher.</source>
         <translation>You changed the language. In order to use the newly selected language, you need to restart OpenTeacher.</translation>
     </message>
@@ -1012,47 +1012,47 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="src/openteacher.py" line="398"/>
+        <location filename="src/openteacher.py" line="411"/>
         <source>Make your choice</source>
         <translation>Make your choice</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="399"/>
+        <location filename="src/openteacher.py" line="412"/>
         <source>System default</source>
         <translation>System default</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="447"/>
+        <location filename="src/openteacher.py" line="460"/>
         <source>Make your choice (all examples are good to bad)</source>
         <translation>Make your choice (all examples are good to bad)</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="448"/>
+        <location filename="src/openteacher.py" line="461"/>
         <source>Percents</source>
         <translation>Percentages</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="449"/>
+        <location filename="src/openteacher.py" line="462"/>
         <source>Dutch</source>
         <translation>Dutch</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="450"/>
+        <location filename="src/openteacher.py" line="463"/>
         <source>American</source>
         <translation>American</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="451"/>
+        <location filename="src/openteacher.py" line="464"/>
         <source>German</source>
         <translation>German</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="452"/>
+        <location filename="src/openteacher.py" line="465"/>
         <source>French</source>
         <translation>French</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="453"/>
+        <location filename="src/openteacher.py" line="466"/>
         <source>ECTS</source>
         <translation>ECTS</translation>
     </message>
@@ -1076,22 +1076,22 @@
 <context>
     <name>WordListTableModel</name>
     <message>
-        <location filename="src/openteacher.py" line="648"/>
+        <location filename="src/openteacher.py" line="661"/>
         <source>Question</source>
         <translation>Question</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="649"/>
+        <location filename="src/openteacher.py" line="662"/>
         <source>Answer</source>
         <translation>Answer</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="650"/>
+        <location filename="src/openteacher.py" line="663"/>
         <source>Second Answer (optional)</source>
         <translation>Second Answer (optional)</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="651"/>
+        <location filename="src/openteacher.py" line="664"/>
         <source>Errors</source>
         <translation>Errors</translation>
     </message>
