@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS><TS version="2.0">
 <context>
     <name>AbortedByUserError</name>
     <message>
@@ -157,7 +157,7 @@
 <context>
     <name>DocumentationDialog</name>
     <message>
-        <location filename="src/openteacher.py" line="343"/>
+        <location filename="src/openteacher.py" line="356"/>
         <source>Documentation</source>
         <translation>Documentation</translation>
     </message>
@@ -198,12 +198,12 @@
     <message>
         <location filename="ui/openteacher.ui" line="81"/>
         <source>Question Language:</source>
-        <translation>Question Language</translation>
+        <translation>Question Langage:</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="94"/>
         <source>Answer Language:</source>
-        <translation>Réponce Language</translation>
+        <translation>Réponse Langage</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="874"/>
@@ -628,7 +628,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="294"/>
         <source>Click here to remove the selected row(s) from the word list table.</source>
-        <translation type="unfinished"></translation>
+        <translation>Cliquez ici pour supprimer la(les) ligne(s) sélectionnée(s) de la table de la liste des mots.</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="628"/>
@@ -679,197 +679,197 @@
 <context>
     <name>OpenTeacher</name>
     <message>
-        <location filename="src/openteacher.py" line="207"/>
+        <location filename="src/openteacher.py" line="220"/>
         <source>Code</source>
         <translation>Code</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="212"/>
+        <location filename="src/openteacher.py" line="225"/>
         <source>Localisation</source>
         <translation>Localisation</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="306"/>
+        <location filename="src/openteacher.py" line="319"/>
         <source>License</source>
         <translation>Licence</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1233"/>
+        <location filename="src/openteacher.py" line="1250"/>
         <source>No selection was detected.</source>
         <translation>Aucune sélection n&apos;a été détecté.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1507"/>
+        <location filename="src/openteacher.py" line="1530"/>
         <source>Correct answer</source>
         <translation>Bonne réponse</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1593"/>
+        <location filename="src/openteacher.py" line="1625"/>
         <source>Translation: </source>
         <translation>Traduction :</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1602"/>
+        <location filename="src/openteacher.py" line="1634"/>
         <source>Think about the answer, and press the &apos;View answer&apos; button when you&apos;re done.</source>
         <translation>Pensez à la réponse, et appuyez sur le bouton &quot;Voir réponse&quot; lorsque vous avez terminé.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1677"/>
+        <location filename="src/openteacher.py" line="1733"/>
         <source>Hint:</source>
         <translation>Conseil:</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1670"/>
+        <location filename="src/openteacher.py" line="1726"/>
         <source>Click the button to start.</source>
         <translation>Cliquez sur le bouton pour démarrer.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1732"/>
+        <location filename="src/openteacher.py" line="1788"/>
         <source>Test completed!</source>
         <translation>test terminé!</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1732"/>
+        <location filename="src/openteacher.py" line="1788"/>
         <source>Test completed! Your note:</source>
         <translation>test terminé! Votre note:</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1884"/>
+        <location filename="src/openteacher.py" line="1940"/>
         <source>Message</source>
         <translation>Message</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1884"/>
+        <location filename="src/openteacher.py" line="1940"/>
         <source>Do you want to save changes?</source>
         <translation>Voulez-vous enregistrer les modifications ?</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1904"/>
+        <location filename="src/openteacher.py" line="1960"/>
         <source>Exit lesson</source>
         <translation>Sortir de la leçon</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1904"/>
+        <location filename="src/openteacher.py" line="1960"/>
         <source>Are you sure you want to stop the lesson?</source>
         <translation>ete-vous sure de vouloir stopper la leçon</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1948"/>
+        <location filename="src/openteacher.py" line="2004"/>
         <source>Supported</source>
         <translation>Pris en charge</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2027"/>
+        <location filename="src/openteacher.py" line="2083"/>
         <source>Plain text</source>
         <translation>Texte simple</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2042"/>
+        <location filename="src/openteacher.py" line="2098"/>
         <source>Save...</source>
         <translation>Sauvegarder...</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2184"/>
+        <location filename="src/openteacher.py" line="2240"/>
         <source>Print Document</source>
         <translation>Imprimer le document</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2236"/>
+        <location filename="src/openteacher.py" line="2292"/>
         <source>Error</source>
         <translation>Erreur</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="254"/>
+        <location filename="src/openteacher.py" line="267"/>
         <source>OpenTeacher authors</source>
         <translation>OpenTeacher: les auteurs</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1194"/>
+        <location filename="src/openteacher.py" line="1211"/>
         <source>The word(s) were entered successfully.</source>
         <translation>Le mot (s) ont été conclus avec succès.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1230"/>
+        <location filename="src/openteacher.py" line="1247"/>
         <source>The word(s) were removed successfully.</source>
         <translation>Le mot (s) ont été retirées avec succès.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1832"/>
+        <location filename="src/openteacher.py" line="1888"/>
         <source>The wordlist from WRTS was imported successfully.</source>
         <translation>la wordlist par WRTS a été importé avec succès.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1862"/>
+        <location filename="src/openteacher.py" line="1918"/>
         <source>Export successful</source>
         <translation>L&apos;exportation a réussi</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1863"/>
+        <location filename="src/openteacher.py" line="1919"/>
         <source>Word list exported to WRTS.</source>
         <translation>Liste de mots exportés vers WRTS</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1938"/>
+        <location filename="src/openteacher.py" line="1994"/>
         <source>New file created.</source>
         <translation>Nouveau fichier créé.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1966"/>
+        <location filename="src/openteacher.py" line="2022"/>
         <source>The selected file was opened successfully.</source>
         <translation>Le fichier sélectionné a été ouvert avec succès.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2109"/>
+        <location filename="src/openteacher.py" line="2165"/>
         <source>File saved.</source>
         <translation>Fichier enregistré.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2190"/>
+        <location filename="src/openteacher.py" line="2246"/>
         <source>The file was printed successfully.</source>
         <translation>Le fichier a été correctement imprimé.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="254"/>
+        <location filename="src/openteacher.py" line="267"/>
         <source>Project website</source>
         <translation>Site web du projet</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="251"/>
+        <location filename="src/openteacher.py" line="264"/>
         <source>OpenTeacher helps you learn a foreign language vocabulary.</source>
         <translation>OpenTeacher vous aide à apprendre un vocabulaire en langue étrangère.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>een = one</source>
         <translation>un = one</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>twee = two</source>
         <translation>deux = two</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>drie = three</source>
         <translation>trois = three</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>Warning</source>
         <translation>AVERTISSEMENT</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>This credentials are saved in plain text on your harddrive.</source>
         <translation>Cette identification sont enregistrés en texte clair sur votre disque dur.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>Don&apos;t use this function on a public computer!</source>
         <translation>Ne pas utiliser cette fonction sur un ordinateur public!</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1948"/>
+        <location filename="src/openteacher.py" line="2004"/>
         <source>Open...</source>
         <translation>Ouvrir ...</translation>
     </message>
@@ -885,72 +885,72 @@
 <context>
     <name>QDialogButtonBox</name>
     <message>
-        <location filename="src/openteacher.py" line="188"/>
+        <location filename="src/openteacher.py" line="201"/>
         <source>Close without Saving</source>
         <translation>Fermer sans sauvegarder</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="175"/>
+        <location filename="src/openteacher.py" line="188"/>
         <source>&amp;OK</source>
         <translation>&amp;Ok</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="177"/>
+        <location filename="src/openteacher.py" line="190"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Annuler</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="183"/>
+        <location filename="src/openteacher.py" line="196"/>
         <source>&amp;Save</source>
         <translation>&amp;Sauvagarder</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="179"/>
+        <location filename="src/openteacher.py" line="192"/>
         <source>&amp;Yes</source>
         <translation>&amp;Oui</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="180"/>
+        <location filename="src/openteacher.py" line="193"/>
         <source>&amp;No</source>
         <translation>&amp;Non</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="174"/>
+        <location filename="src/openteacher.py" line="187"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="176"/>
+        <location filename="src/openteacher.py" line="189"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="182"/>
+        <location filename="src/openteacher.py" line="195"/>
         <source>Save</source>
         <translation>Sauvegarder</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="184"/>
+        <location filename="src/openteacher.py" line="197"/>
         <source>Open</source>
         <translation>Ouvrir</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="185"/>
+        <location filename="src/openteacher.py" line="198"/>
         <source>Close</source>
         <translation>Fermer</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="186"/>
+        <location filename="src/openteacher.py" line="199"/>
         <source>&amp;Close</source>
         <translation>&amp;Fermer</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="189"/>
+        <location filename="src/openteacher.py" line="202"/>
         <source>Don&apos;t save</source>
         <translation>Ne pas sauvegarder</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="190"/>
+        <location filename="src/openteacher.py" line="203"/>
         <source>Discard</source>
         <translation>Abandonner</translation>
     </message>
@@ -958,22 +958,22 @@
 <context>
     <name>QShortcut</name>
     <message>
-        <location filename="src/openteacher.py" line="193"/>
+        <location filename="src/openteacher.py" line="206"/>
         <source>Ctrl</source>
         <translation>Ctrl</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="194"/>
+        <location filename="src/openteacher.py" line="207"/>
         <source>Return</source>
         <translation>Entrée</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="195"/>
+        <location filename="src/openteacher.py" line="208"/>
         <source>Del</source>
         <translation>Suppr</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="196"/>
+        <location filename="src/openteacher.py" line="209"/>
         <source>Shift</source>
         <translation>Shift</translation>
     </message>
@@ -989,22 +989,22 @@
 <context>
     <name>Settings</name>
     <message>
-        <location filename="src/openteacher.py" line="513"/>
+        <location filename="src/openteacher.py" line="526"/>
         <source>Restart please</source>
         <translation>Redémarrez s&apos;il vous plaît</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="484"/>
+        <location filename="src/openteacher.py" line="497"/>
         <source>Connection to WRTS failed</source>
         <translation>La connexion WRTS à échoué</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="487"/>
+        <location filename="src/openteacher.py" line="500"/>
         <source>Connection to WRTS succeeded</source>
         <translation>La connexion  WRTS à réussi</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="513"/>
+        <location filename="src/openteacher.py" line="526"/>
         <source>You changed the language. In order to use the newly selected language, you need to restart OpenTeacher.</source>
         <translation>Vous avez changé la langue. Afin d&apos;utiliser la langue nouvellement sélectionnée, vous devez redémarrer OpenTeacher.</translation>
     </message>
@@ -1012,47 +1012,47 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="src/openteacher.py" line="398"/>
+        <location filename="src/openteacher.py" line="411"/>
         <source>Make your choice</source>
         <translation>Faitre votre choix</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="399"/>
+        <location filename="src/openteacher.py" line="412"/>
         <source>System default</source>
         <translation>Système par défaut</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="447"/>
+        <location filename="src/openteacher.py" line="460"/>
         <source>Make your choice (all examples are good to bad)</source>
         <translation>Faites votre choix (tous les exemples sont de bon au mauvais)</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="448"/>
+        <location filename="src/openteacher.py" line="461"/>
         <source>Percents</source>
         <translation>Pourcentages</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="449"/>
+        <location filename="src/openteacher.py" line="462"/>
         <source>Dutch</source>
         <translation>Hollandais</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="450"/>
+        <location filename="src/openteacher.py" line="463"/>
         <source>American</source>
         <translation>Américain</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="451"/>
+        <location filename="src/openteacher.py" line="464"/>
         <source>German</source>
         <translation>Allemand</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="452"/>
+        <location filename="src/openteacher.py" line="465"/>
         <source>French</source>
         <translation>Français</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="453"/>
+        <location filename="src/openteacher.py" line="466"/>
         <source>ECTS</source>
         <translation>ECTS</translation>
     </message>
@@ -1076,22 +1076,22 @@
 <context>
     <name>WordListTableModel</name>
     <message>
-        <location filename="src/openteacher.py" line="648"/>
+        <location filename="src/openteacher.py" line="661"/>
         <source>Question</source>
         <translation>Question</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="649"/>
+        <location filename="src/openteacher.py" line="662"/>
         <source>Answer</source>
         <translation>Réponse</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="650"/>
+        <location filename="src/openteacher.py" line="663"/>
         <source>Second Answer (optional)</source>
         <translation>Seconde réponse (optionnel)</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="651"/>
+        <location filename="src/openteacher.py" line="664"/>
         <source>Errors</source>
         <translation>Erreurs</translation>
     </message>
