@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS><TS version="2.0">
 <context>
     <name>AbortedByUserError</name>
     <message>
@@ -13,7 +13,7 @@
     <message>
         <location filename="src/errors.py" line="55"/>
         <source>Could not open file because its contents are invalid, or written in a way not supported by OpenTeacher.</source>
-        <translation>Could not open file because its contents are invalid, or written in a way not supported by OpenTeacher.</translation>
+        <translation>Nem sikerült a fájl megnyitása, mert érvénytelen a tartalma vagy az OpenTeacher által nem támogatott formátum.</translation>
     </message>
 </context>
 <context>
@@ -121,7 +121,7 @@
     <message>
         <location filename="ui/settings.ui" line="168"/>
         <source>Note notation:</source>
-        <translation>Hangzás jelölése:</translation>
+        <translation>Eredmény jelölése:</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="183"/>
@@ -157,7 +157,7 @@
 <context>
     <name>DocumentationDialog</name>
     <message>
-        <location filename="src/openteacher.py" line="343"/>
+        <location filename="src/openteacher.py" line="356"/>
         <source>Documentation</source>
         <translation>Dokumentáció</translation>
     </message>
@@ -438,7 +438,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="1050"/>
         <source>Note:</source>
-        <translation>Megjegyzés:</translation>
+        <translation>Eredmény:</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="1093"/>
@@ -478,7 +478,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="1178"/>
         <source>Open an existing file.</source>
-        <translation>Létező fájl megnyitása</translation>
+        <translation>Létező fájl megnyitása.</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="1181"/>
@@ -523,7 +523,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="1223"/>
         <source>View information about OpenTeacher.</source>
-        <translation>OpenTeacher információk megjelenítése</translation>
+        <translation>OpenTeacher információk megjelenítése.</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="1232"/>
@@ -628,12 +628,12 @@
     <message>
         <location filename="ui/openteacher.ui" line="294"/>
         <source>Click here to remove the selected row(s) from the word list table.</source>
-        <translation type="unfinished"></translation>
+        <translation>Kattintson ide a szólista kijelölt sorainak törléséhez.</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="628"/>
         <source>Think answer</source>
-        <translation type="unfinished"></translation>
+        <translation>Válasz kigondolása</translation>
     </message>
 </context>
 <context>
@@ -679,197 +679,197 @@
 <context>
     <name>OpenTeacher</name>
     <message>
-        <location filename="src/openteacher.py" line="207"/>
+        <location filename="src/openteacher.py" line="220"/>
         <source>Code</source>
         <translation>Kód</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="212"/>
+        <location filename="src/openteacher.py" line="225"/>
         <source>Localisation</source>
         <translation>Lokalizáció</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="306"/>
+        <location filename="src/openteacher.py" line="319"/>
         <source>License</source>
         <translation>Licenc</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1233"/>
+        <location filename="src/openteacher.py" line="1250"/>
         <source>No selection was detected.</source>
         <translation>Nincs felismerhető választás.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1507"/>
+        <location filename="src/openteacher.py" line="1530"/>
         <source>Correct answer</source>
         <translation>Helyes válasz</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1593"/>
+        <location filename="src/openteacher.py" line="1625"/>
         <source>Translation: </source>
         <translation>Fordítás:</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1602"/>
+        <location filename="src/openteacher.py" line="1634"/>
         <source>Think about the answer, and press the &apos;View answer&apos; button when you&apos;re done.</source>
-        <translation>Gondolja ki a választ, majd nyomja meg a &quot;Válasz mutatása&quot; gombot, amikor készen van.</translation>
+        <translation>Gondolja ki a választ, majd nyomja meg a „Válasz megtekintése” gombot, amikor készen van.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1677"/>
+        <location filename="src/openteacher.py" line="1733"/>
         <source>Hint:</source>
         <translation>Tipp:</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1670"/>
+        <location filename="src/openteacher.py" line="1726"/>
         <source>Click the button to start.</source>
         <translation>Az indításhoz kattintson a gombra.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1732"/>
+        <location filename="src/openteacher.py" line="1788"/>
         <source>Test completed!</source>
         <translation>Teszt kész!</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1732"/>
+        <location filename="src/openteacher.py" line="1788"/>
         <source>Test completed! Your note:</source>
-        <translation>Teszt kész! Az ön eredménye:</translation>
+        <translation>Kész a teszt! Az Ön eredménye:</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1884"/>
+        <location filename="src/openteacher.py" line="1940"/>
         <source>Message</source>
         <translation>Üzenet</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1884"/>
+        <location filename="src/openteacher.py" line="1940"/>
         <source>Do you want to save changes?</source>
         <translation>El szeretné menteni a módosításokat?</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1904"/>
+        <location filename="src/openteacher.py" line="1960"/>
         <source>Exit lesson</source>
         <translation>Kilépés a leckéből</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1904"/>
+        <location filename="src/openteacher.py" line="1960"/>
         <source>Are you sure you want to stop the lesson?</source>
         <translation>Biztosan megállítja a leckét?</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1948"/>
+        <location filename="src/openteacher.py" line="2004"/>
         <source>Supported</source>
         <translation>Támogatott</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2027"/>
+        <location filename="src/openteacher.py" line="2083"/>
         <source>Plain text</source>
         <translation>Egyszerű szöveg</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2042"/>
+        <location filename="src/openteacher.py" line="2098"/>
         <source>Save...</source>
         <translation>Mentés…</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2184"/>
+        <location filename="src/openteacher.py" line="2240"/>
         <source>Print Document</source>
         <translation>Dokumentum nyomtatása</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2236"/>
+        <location filename="src/openteacher.py" line="2292"/>
         <source>Error</source>
         <translation>Hiba</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="254"/>
+        <location filename="src/openteacher.py" line="267"/>
         <source>OpenTeacher authors</source>
         <translation>OpenTeacher készítői</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1194"/>
+        <location filename="src/openteacher.py" line="1211"/>
         <source>The word(s) were entered successfully.</source>
         <translation>A szavak sikeresen betöltve.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1230"/>
+        <location filename="src/openteacher.py" line="1247"/>
         <source>The word(s) were removed successfully.</source>
         <translation>A szavak sikeresen törölve.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1832"/>
+        <location filename="src/openteacher.py" line="1888"/>
         <source>The wordlist from WRTS was imported successfully.</source>
         <translation>A szólista sikeresen importálva a WRTS-ből.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1862"/>
+        <location filename="src/openteacher.py" line="1918"/>
         <source>Export successful</source>
         <translation>Exportálás sikeres</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1863"/>
+        <location filename="src/openteacher.py" line="1919"/>
         <source>Word list exported to WRTS.</source>
         <translation>A szólista sikeresen exportálva a WRTS-be.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1938"/>
+        <location filename="src/openteacher.py" line="1994"/>
         <source>New file created.</source>
         <translation>Az új fájl sikeresen létrehozva.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1966"/>
+        <location filename="src/openteacher.py" line="2022"/>
         <source>The selected file was opened successfully.</source>
         <translation>A kiválasztott fájl sikeresen megnyitva.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2109"/>
+        <location filename="src/openteacher.py" line="2165"/>
         <source>File saved.</source>
         <translation>A fájl sikeresen mentve.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2190"/>
+        <location filename="src/openteacher.py" line="2246"/>
         <source>The file was printed successfully.</source>
         <translation>A fájl sikeresen kinyomtatva.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="254"/>
+        <location filename="src/openteacher.py" line="267"/>
         <source>Project website</source>
         <translation>Projekt weboldala</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="251"/>
+        <location filename="src/openteacher.py" line="264"/>
         <source>OpenTeacher helps you learn a foreign language vocabulary.</source>
-        <translation>Az OpenTeacher segíti önt az idegen nyelv szavainak megtanulásában.</translation>
+        <translation>Az OpenTeacher segíti Önt egy idegennyelv szavainak megtanulásában.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>een = one</source>
         <translation>een = egy</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>twee = two</source>
         <translation>twee = kettő</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>drie = three</source>
         <translation>drie = három</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>Warning</source>
         <translation>Figyelmeztetés</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>This credentials are saved in plain text on your harddrive.</source>
         <translation>Ezek a bizonyítványok egy sima szövegbe vannak mentve a merevlemezén.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>Don&apos;t use this function on a public computer!</source>
         <translation>Ne használja ezt a funkciót nyilvános számítógépen!</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1948"/>
+        <location filename="src/openteacher.py" line="2004"/>
         <source>Open...</source>
         <translation>Megnyitás…</translation>
     </message>
@@ -885,72 +885,72 @@
 <context>
     <name>QDialogButtonBox</name>
     <message>
-        <location filename="src/openteacher.py" line="188"/>
+        <location filename="src/openteacher.py" line="201"/>
         <source>Close without Saving</source>
         <translation>Bezárás mentés nélkül</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="175"/>
+        <location filename="src/openteacher.py" line="188"/>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="177"/>
+        <location filename="src/openteacher.py" line="190"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Mégsem</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="183"/>
+        <location filename="src/openteacher.py" line="196"/>
         <source>&amp;Save</source>
         <translation>Menté&amp;s</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="179"/>
+        <location filename="src/openteacher.py" line="192"/>
         <source>&amp;Yes</source>
         <translation>&amp;Igen</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="180"/>
+        <location filename="src/openteacher.py" line="193"/>
         <source>&amp;No</source>
         <translation>&amp;Nem</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="174"/>
+        <location filename="src/openteacher.py" line="187"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="176"/>
+        <location filename="src/openteacher.py" line="189"/>
         <source>Cancel</source>
         <translation>Mégsem</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="182"/>
+        <location filename="src/openteacher.py" line="195"/>
         <source>Save</source>
         <translation>Mentés</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="184"/>
+        <location filename="src/openteacher.py" line="197"/>
         <source>Open</source>
         <translation>Megnyitás</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="185"/>
+        <location filename="src/openteacher.py" line="198"/>
         <source>Close</source>
         <translation>Bezárás</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="186"/>
+        <location filename="src/openteacher.py" line="199"/>
         <source>&amp;Close</source>
         <translation>&amp;Bezárás</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="189"/>
+        <location filename="src/openteacher.py" line="202"/>
         <source>Don&apos;t save</source>
         <translation>Ne mentse</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="190"/>
+        <location filename="src/openteacher.py" line="203"/>
         <source>Discard</source>
         <translation>Elvetés</translation>
     </message>
@@ -958,22 +958,22 @@
 <context>
     <name>QShortcut</name>
     <message>
-        <location filename="src/openteacher.py" line="193"/>
+        <location filename="src/openteacher.py" line="206"/>
         <source>Ctrl</source>
         <translation>Ctrl</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="194"/>
+        <location filename="src/openteacher.py" line="207"/>
         <source>Return</source>
         <translation>Return</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="195"/>
+        <location filename="src/openteacher.py" line="208"/>
         <source>Del</source>
         <translation>Del</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="196"/>
+        <location filename="src/openteacher.py" line="209"/>
         <source>Shift</source>
         <translation>Shift</translation>
     </message>
@@ -989,22 +989,22 @@
 <context>
     <name>Settings</name>
     <message>
-        <location filename="src/openteacher.py" line="513"/>
+        <location filename="src/openteacher.py" line="526"/>
         <source>Restart please</source>
         <translation>Újraindítás szükséges</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="484"/>
+        <location filename="src/openteacher.py" line="497"/>
         <source>Connection to WRTS failed</source>
         <translation>Kapcsolódás a WRTS-hez sikertelen.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="487"/>
+        <location filename="src/openteacher.py" line="500"/>
         <source>Connection to WRTS succeeded</source>
         <translation>Kapcsolódás a WRTS-hez sikeres</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="513"/>
+        <location filename="src/openteacher.py" line="526"/>
         <source>You changed the language. In order to use the newly selected language, you need to restart OpenTeacher.</source>
         <translation>Megváltoztatta a nyelvet. Annak érdekében, hogy használatba lépjen az újonnan választott nyelv, indítsa újra az OpenTeacher-t.</translation>
     </message>
@@ -1012,47 +1012,47 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="src/openteacher.py" line="398"/>
+        <location filename="src/openteacher.py" line="411"/>
         <source>Make your choice</source>
         <translation>Válasszon!</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="399"/>
+        <location filename="src/openteacher.py" line="412"/>
         <source>System default</source>
         <translation>Alapértelmezett</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="447"/>
+        <location filename="src/openteacher.py" line="460"/>
         <source>Make your choice (all examples are good to bad)</source>
-        <translation>Make your choice (all examples are good to bad)</translation>
+        <translation>Válasszon (az összes példa értékelése jótól–rosszig halad)</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="448"/>
+        <location filename="src/openteacher.py" line="461"/>
         <source>Percents</source>
         <translation>Százalék</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="449"/>
+        <location filename="src/openteacher.py" line="462"/>
         <source>Dutch</source>
         <translation>holland</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="450"/>
+        <location filename="src/openteacher.py" line="463"/>
         <source>American</source>
         <translation>amerikai</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="451"/>
+        <location filename="src/openteacher.py" line="464"/>
         <source>German</source>
         <translation>német</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="452"/>
+        <location filename="src/openteacher.py" line="465"/>
         <source>French</source>
         <translation>francia</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="453"/>
+        <location filename="src/openteacher.py" line="466"/>
         <source>ECTS</source>
         <translation>ECTS</translation>
     </message>
@@ -1076,22 +1076,22 @@
 <context>
     <name>WordListTableModel</name>
     <message>
-        <location filename="src/openteacher.py" line="648"/>
+        <location filename="src/openteacher.py" line="661"/>
         <source>Question</source>
         <translation>Kérdés</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="649"/>
+        <location filename="src/openteacher.py" line="662"/>
         <source>Answer</source>
         <translation>Válasz</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="650"/>
+        <location filename="src/openteacher.py" line="663"/>
         <source>Second Answer (optional)</source>
         <translation>Második válasz (opcionális)</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="651"/>
+        <location filename="src/openteacher.py" line="664"/>
         <source>Errors</source>
         <translation>Hibák</translation>
     </message>
@@ -1101,7 +1101,7 @@
     <message>
         <location filename="src/errors.py" line="83"/>
         <source>WRTS didn&apos;t accept the connection. Are you sure that your internet connection works and WRTS is online?</source>
-        <translation>A WRTS nem fogadta a kapcsolatot. Biztos, hogy az Internet működik és a WRTS is online?</translation>
+        <translation>Nem sikerült kapcsolódni a WRTS kiszolgálóhoz. Működik az internet kapcsolata és a WRTS honlapja is elérhető?</translation>
     </message>
 </context>
 <context>
