@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS><TS version="2.0">
 <context>
     <name>AbortedByUserError</name>
     <message>
@@ -41,7 +41,7 @@
     <message>
         <location filename="ui/about.ui" line="195"/>
         <source>Authors</source>
-        <translation type="unfinished"></translation>
+        <translation>Ophavsmenn</translation>
     </message>
     <message>
         <location filename="ui/about.ui" line="208"/>
@@ -106,7 +106,7 @@
     <message>
         <location filename="ui/settings.ui" line="98"/>
         <source>Fade duration when wrong:</source>
-        <translation type="unfinished"></translation>
+        <translation>Uttoningstid ved feil:</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="155"/>
@@ -157,7 +157,7 @@
 <context>
     <name>DocumentationDialog</name>
     <message>
-        <location filename="src/openteacher.py" line="343"/>
+        <location filename="src/openteacher.py" line="356"/>
         <source>Documentation</source>
         <translation>Dokumentasjon</translation>
     </message>
@@ -268,7 +268,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="386"/>
         <source>Ask smart (ideal for practising)</source>
-        <translation type="unfinished"></translation>
+        <translation>Spør smart (ideelt for pugging)</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="396"/>
@@ -318,7 +318,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="453"/>
         <source>All</source>
-        <translation type="unfinished"></translation>
+        <translation>Alle</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="458"/>
@@ -358,7 +358,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="791"/>
         <source>Return</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Linjeskift</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="798"/>
@@ -408,7 +408,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="766"/>
         <source>Hint:</source>
-        <translation type="unfinished"></translation>
+        <translation>Hint:</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="755"/>
@@ -428,7 +428,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="1057"/>
         <source>0</source>
-        <translation type="unfinished"></translation>
+        <translation>0</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="1036"/>
@@ -538,7 +538,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="1238"/>
         <source>Ctrl+Shift+S</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl + Shift + S</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="1247"/>
@@ -608,32 +608,32 @@
     <message>
         <location filename="ui/openteacher.ui" line="391"/>
         <source>Interval training</source>
-        <translation type="unfinished"></translation>
+        <translation>Intervalltrening</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="1316"/>
         <source>Documentation</source>
-        <translation type="unfinished">Dokumentasjon</translation>
+        <translation>Dokumentasjon</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="844"/>
         <source>Change lesson settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Endre instillinger for økten</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="484"/>
         <source>Back to the lesson</source>
-        <translation type="unfinished"></translation>
+        <translation>Tilbake til økten</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="294"/>
         <source>Click here to remove the selected row(s) from the word list table.</source>
-        <translation type="unfinished"></translation>
+        <translation>Trykk her for å ta bort de valgte radene fra listen.</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="628"/>
         <source>Think answer</source>
-        <translation type="unfinished"></translation>
+        <translation>Tenk svaret</translation>
     </message>
 </context>
 <context>
@@ -679,199 +679,199 @@
 <context>
     <name>OpenTeacher</name>
     <message>
-        <location filename="src/openteacher.py" line="207"/>
+        <location filename="src/openteacher.py" line="220"/>
         <source>Code</source>
-        <translation type="unfinished"></translation>
+        <translation>Kode</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="212"/>
+        <location filename="src/openteacher.py" line="225"/>
         <source>Localisation</source>
-        <translation type="unfinished"></translation>
+        <translation>Lokalisering</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="306"/>
+        <location filename="src/openteacher.py" line="319"/>
         <source>License</source>
-        <translation type="unfinished">Lisens</translation>
+        <translation>Lisens</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1233"/>
+        <location filename="src/openteacher.py" line="1250"/>
         <source>No selection was detected.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1507"/>
+        <location filename="src/openteacher.py" line="1530"/>
         <source>Correct answer</source>
-        <translation type="unfinished"></translation>
+        <translation>Riktig svar</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1593"/>
+        <location filename="src/openteacher.py" line="1625"/>
         <source>Translation: </source>
-        <translation type="unfinished"></translation>
+        <translation>Oversettelse:</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1602"/>
+        <location filename="src/openteacher.py" line="1634"/>
         <source>Think about the answer, and press the &apos;View answer&apos; button when you&apos;re done.</source>
-        <translation type="unfinished"></translation>
+        <translation>Tenk på svaret, og trykk deretter på «Vis svaret»-knappen.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1677"/>
+        <location filename="src/openteacher.py" line="1733"/>
         <source>Hint:</source>
-        <translation type="unfinished"></translation>
+        <translation>Hint:</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1670"/>
+        <location filename="src/openteacher.py" line="1726"/>
         <source>Click the button to start.</source>
-        <translation type="unfinished"></translation>
+        <translation>Trykk på knappen for å starte</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1732"/>
+        <location filename="src/openteacher.py" line="1788"/>
         <source>Test completed!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1732"/>
+        <location filename="src/openteacher.py" line="1788"/>
         <source>Test completed! Your note:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1884"/>
+        <location filename="src/openteacher.py" line="1940"/>
         <source>Message</source>
-        <translation type="unfinished"></translation>
+        <translation>Melding</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1884"/>
+        <location filename="src/openteacher.py" line="1940"/>
         <source>Do you want to save changes?</source>
-        <translation type="unfinished"></translation>
+        <translation>Vil du lagre endringene?</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1904"/>
+        <location filename="src/openteacher.py" line="1960"/>
         <source>Exit lesson</source>
-        <translation type="unfinished"></translation>
+        <translation>Avslutt økten</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1904"/>
+        <location filename="src/openteacher.py" line="1960"/>
         <source>Are you sure you want to stop the lesson?</source>
-        <translation type="unfinished"></translation>
+        <translation>Er du sikker på at du vil avslutte økten?</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1948"/>
+        <location filename="src/openteacher.py" line="2004"/>
         <source>Supported</source>
-        <translation type="unfinished"></translation>
+        <translation>Støttet</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2027"/>
+        <location filename="src/openteacher.py" line="2083"/>
         <source>Plain text</source>
-        <translation type="unfinished"></translation>
+        <translation>Ren tekst</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2042"/>
+        <location filename="src/openteacher.py" line="2098"/>
         <source>Save...</source>
-        <translation type="unfinished"></translation>
+        <translation>Lagre …</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2184"/>
+        <location filename="src/openteacher.py" line="2240"/>
         <source>Print Document</source>
-        <translation type="unfinished"></translation>
+        <translation>Skriv ut dokument</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2236"/>
+        <location filename="src/openteacher.py" line="2292"/>
         <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Feil</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="254"/>
+        <location filename="src/openteacher.py" line="267"/>
         <source>OpenTeacher authors</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1194"/>
+        <location filename="src/openteacher.py" line="1211"/>
         <source>The word(s) were entered successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1230"/>
+        <location filename="src/openteacher.py" line="1247"/>
         <source>The word(s) were removed successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1832"/>
+        <location filename="src/openteacher.py" line="1888"/>
         <source>The wordlist from WRTS was imported successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1862"/>
+        <location filename="src/openteacher.py" line="1918"/>
         <source>Export successful</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1863"/>
+        <location filename="src/openteacher.py" line="1919"/>
         <source>Word list exported to WRTS.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1938"/>
+        <location filename="src/openteacher.py" line="1994"/>
         <source>New file created.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1966"/>
+        <location filename="src/openteacher.py" line="2022"/>
         <source>The selected file was opened successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2109"/>
+        <location filename="src/openteacher.py" line="2165"/>
         <source>File saved.</source>
-        <translation type="unfinished"></translation>
+        <translation>Filen ble lagret.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2190"/>
+        <location filename="src/openteacher.py" line="2246"/>
         <source>The file was printed successfully.</source>
-        <translation type="unfinished"></translation>
+        <translation>Filen ble skrevet ut uten problemer.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="254"/>
+        <location filename="src/openteacher.py" line="267"/>
         <source>Project website</source>
-        <translation type="unfinished"></translation>
+        <translation>Prosjektets nettside</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="251"/>
+        <location filename="src/openteacher.py" line="264"/>
         <source>OpenTeacher helps you learn a foreign language vocabulary.</source>
-        <translation type="unfinished"></translation>
+        <translation>OpenTeacher hjelper deg å lære ord på fremmede språk.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>een = one</source>
-        <translation type="unfinished"></translation>
+        <translation>een = en</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>twee = two</source>
-        <translation type="unfinished"></translation>
+        <translation>twee = to</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>drie = three</source>
-        <translation type="unfinished"></translation>
+        <translation>drie = tre</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>Warning</source>
-        <translation type="unfinished"></translation>
+        <translation>Advarsel</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>This credentials are saved in plain text on your harddrive.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>Don&apos;t use this function on a public computer!</source>
-        <translation type="unfinished"></translation>
+        <translation>Ikke bruk denne funksjonen på en offentlig datamaskin!</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1948"/>
+        <location filename="src/openteacher.py" line="2004"/>
         <source>Open...</source>
-        <translation type="unfinished"></translation>
+        <translation>Åpne …</translation>
     </message>
 </context>
 <context>
@@ -879,103 +879,103 @@
     <message>
         <location filename="src/errors.py" line="35"/>
         <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Feil</translation>
     </message>
 </context>
 <context>
     <name>QDialogButtonBox</name>
     <message>
-        <location filename="src/openteacher.py" line="188"/>
+        <location filename="src/openteacher.py" line="201"/>
         <source>Close without Saving</source>
-        <translation type="unfinished"></translation>
+        <translation>Lukk uten å lagre</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="175"/>
+        <location filename="src/openteacher.py" line="188"/>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="src/openteacher.py" line="177"/>
-        <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="src/openteacher.py" line="183"/>
-        <source>&amp;Save</source>
-        <translation type="unfinished">&amp;Lagre</translation>
-    </message>
-    <message>
-        <location filename="src/openteacher.py" line="179"/>
-        <source>&amp;Yes</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="src/openteacher.py" line="180"/>
-        <source>&amp;No</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="src/openteacher.py" line="174"/>
-        <source>OK</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="src/openteacher.py" line="176"/>
-        <source>Cancel</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="src/openteacher.py" line="182"/>
-        <source>Save</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="src/openteacher.py" line="184"/>
-        <source>Open</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="src/openteacher.py" line="185"/>
-        <source>Close</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="src/openteacher.py" line="186"/>
-        <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="src/openteacher.py" line="189"/>
-        <source>Don&apos;t save</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;OK</translation>
     </message>
     <message>
         <location filename="src/openteacher.py" line="190"/>
+        <source>&amp;Cancel</source>
+        <translation>&amp;Avbryt</translation>
+    </message>
+    <message>
+        <location filename="src/openteacher.py" line="196"/>
+        <source>&amp;Save</source>
+        <translation>&amp;Lagre</translation>
+    </message>
+    <message>
+        <location filename="src/openteacher.py" line="192"/>
+        <source>&amp;Yes</source>
+        <translation>&amp;Ja</translation>
+    </message>
+    <message>
+        <location filename="src/openteacher.py" line="193"/>
+        <source>&amp;No</source>
+        <translation>&amp;Nei</translation>
+    </message>
+    <message>
+        <location filename="src/openteacher.py" line="187"/>
+        <source>OK</source>
+        <translation>OK</translation>
+    </message>
+    <message>
+        <location filename="src/openteacher.py" line="189"/>
+        <source>Cancel</source>
+        <translation>Avbryt</translation>
+    </message>
+    <message>
+        <location filename="src/openteacher.py" line="195"/>
+        <source>Save</source>
+        <translation>Lagre</translation>
+    </message>
+    <message>
+        <location filename="src/openteacher.py" line="197"/>
+        <source>Open</source>
+        <translation>Åpne</translation>
+    </message>
+    <message>
+        <location filename="src/openteacher.py" line="198"/>
+        <source>Close</source>
+        <translation>Lukk</translation>
+    </message>
+    <message>
+        <location filename="src/openteacher.py" line="199"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Lukk</translation>
+    </message>
+    <message>
+        <location filename="src/openteacher.py" line="202"/>
+        <source>Don&apos;t save</source>
+        <translation>Ikke lagre</translation>
+    </message>
+    <message>
+        <location filename="src/openteacher.py" line="203"/>
         <source>Discard</source>
-        <translation type="unfinished"></translation>
+        <translation>Forkast</translation>
     </message>
 </context>
 <context>
     <name>QShortcut</name>
     <message>
-        <location filename="src/openteacher.py" line="193"/>
+        <location filename="src/openteacher.py" line="206"/>
         <source>Ctrl</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="194"/>
+        <location filename="src/openteacher.py" line="207"/>
         <source>Return</source>
-        <translation type="unfinished"></translation>
+        <translation>Linjeskift</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="195"/>
+        <location filename="src/openteacher.py" line="208"/>
         <source>Del</source>
         <translation type="unfinished">Fjern</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="196"/>
+        <location filename="src/openteacher.py" line="209"/>
         <source>Shift</source>
-        <translation type="unfinished"></translation>
+        <translation>Shift</translation>
     </message>
 </context>
 <context>
@@ -989,22 +989,22 @@
 <context>
     <name>Settings</name>
     <message>
-        <location filename="src/openteacher.py" line="513"/>
+        <location filename="src/openteacher.py" line="526"/>
         <source>Restart please</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="484"/>
+        <location filename="src/openteacher.py" line="497"/>
         <source>Connection to WRTS failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="487"/>
+        <location filename="src/openteacher.py" line="500"/>
         <source>Connection to WRTS succeeded</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="513"/>
+        <location filename="src/openteacher.py" line="526"/>
         <source>You changed the language. In order to use the newly selected language, you need to restart OpenTeacher.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1012,47 +1012,47 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="src/openteacher.py" line="398"/>
+        <location filename="src/openteacher.py" line="411"/>
         <source>Make your choice</source>
-        <translation type="unfinished"></translation>
+        <translation>Gjør et valg</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="399"/>
+        <location filename="src/openteacher.py" line="412"/>
         <source>System default</source>
-        <translation type="unfinished"></translation>
+        <translation>Systemstandard</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="447"/>
+        <location filename="src/openteacher.py" line="460"/>
         <source>Make your choice (all examples are good to bad)</source>
-        <translation type="unfinished"></translation>
+        <translation>Gjør et valg (eksemplene er i rekkefølgen best til verst)</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="448"/>
+        <location filename="src/openteacher.py" line="461"/>
         <source>Percents</source>
-        <translation type="unfinished"></translation>
+        <translation>Prosent</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="449"/>
+        <location filename="src/openteacher.py" line="462"/>
         <source>Dutch</source>
-        <translation type="unfinished"></translation>
+        <translation>Nederlandsk</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="450"/>
+        <location filename="src/openteacher.py" line="463"/>
         <source>American</source>
-        <translation type="unfinished"></translation>
+        <translation>Amerikansk</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="451"/>
+        <location filename="src/openteacher.py" line="464"/>
         <source>German</source>
-        <translation type="unfinished"></translation>
+        <translation>Tysk</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="452"/>
+        <location filename="src/openteacher.py" line="465"/>
         <source>French</source>
-        <translation type="unfinished"></translation>
+        <translation>Fransk</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="453"/>
+        <location filename="src/openteacher.py" line="466"/>
         <source>ECTS</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1076,24 +1076,24 @@
 <context>
     <name>WordListTableModel</name>
     <message>
-        <location filename="src/openteacher.py" line="648"/>
+        <location filename="src/openteacher.py" line="661"/>
         <source>Question</source>
-        <translation type="unfinished"></translation>
+        <translation>Spørsmål</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="649"/>
+        <location filename="src/openteacher.py" line="662"/>
         <source>Answer</source>
-        <translation type="unfinished"></translation>
+        <translation>Svar</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="650"/>
+        <location filename="src/openteacher.py" line="663"/>
         <source>Second Answer (optional)</source>
-        <translation type="unfinished"></translation>
+        <translation>Annet svar (valgfri)</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="651"/>
+        <location filename="src/openteacher.py" line="664"/>
         <source>Errors</source>
-        <translation type="unfinished"></translation>
+        <translation>Feil</translation>
     </message>
 </context>
 <context>
