@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS><TS version="2.0">
 <context>
     <name>AbortedByUserError</name>
     <message>
@@ -13,7 +13,7 @@
     <message>
         <location filename="src/errors.py" line="55"/>
         <source>Could not open file because its contents are invalid, or written in a way not supported by OpenTeacher.</source>
-        <translation>Nie można otworzyć pliku, ponieważ jego zawartość jest nieprawidłowa lub zapisana w sposób nieobsługiwany przez program OpenTeacher.</translation>
+        <translation>Nie można otworzyć pliku, ponieważ jego zawartość jest niepoprawna lub nie może być odczytana przez program OpenTeacher.</translation>
     </message>
 </context>
 <context>
@@ -26,7 +26,7 @@
     <message>
         <location filename="ui/about.ui" line="28"/>
         <source>About</source>
-        <translation>O programie</translation>
+        <translation>O</translation>
     </message>
     <message>
         <location filename="ui/about.ui" line="106"/>
@@ -41,12 +41,12 @@
     <message>
         <location filename="ui/about.ui" line="195"/>
         <source>Authors</source>
-        <translation>Autorzy</translation>
+        <translation>Autorzy tekstów</translation>
     </message>
     <message>
         <location filename="ui/about.ui" line="208"/>
         <source>Name</source>
-        <translation type="unfinished"></translation>
+        <translation>Imię / Nazwisko</translation>
     </message>
     <message>
         <location filename="ui/wrtsLogin.ui" line="13"/>
@@ -56,12 +56,12 @@
     <message>
         <location filename="ui/wrtsLogin.ui" line="22"/>
         <source>E-mail</source>
-        <translation>E-mail</translation>
+        <translation>Adres e-mail</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="199"/>
         <source>Password:</source>
-        <translation>Hasło         :</translation>
+        <translation>Hasło</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="14"/>
@@ -71,7 +71,7 @@
     <message>
         <location filename="ui/settings.ui" line="24"/>
         <source>General</source>
-        <translation>Główne</translation>
+        <translation>Uwagi ogólne</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="32"/>
@@ -81,7 +81,7 @@
     <message>
         <location filename="ui/settings.ui" line="44"/>
         <source>Show &apos;overwrite&apos;-dialogs</source>
-        <translation type="unfinished"></translation>
+        <translation>Pokaż okna dialogowe &apos;zastąp&apos;</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="57"/>
@@ -141,7 +141,7 @@
     <message>
         <location filename="ui/about.ui" line="216"/>
         <source>Thanks to all Launchpad contributors!</source>
-        <translation type="unfinished"></translation>
+        <translation>Dziękujemy wszystkim uczestnikom projektu!</translation>
     </message>
     <message>
         <location filename="ui/wrtsListChoice.ui" line="14"/>
@@ -157,7 +157,7 @@
 <context>
     <name>DocumentationDialog</name>
     <message>
-        <location filename="src/openteacher.py" line="343"/>
+        <location filename="src/openteacher.py" line="356"/>
         <source>Documentation</source>
         <translation>Dokumentacja</translation>
     </message>
@@ -167,7 +167,7 @@
     <message>
         <location filename="src/errors.py" line="59"/>
         <source>There seems to be no content in the input area</source>
-        <translation>Wygląda na to, że nie ma żadnej treści w polu wprowadzania</translation>
+        <translation>Wydaje się, że nie ma żadnej treści w polu wprowadzania</translation>
     </message>
 </context>
 <context>
@@ -193,7 +193,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="68"/>
         <source>Title:</source>
-        <translation>Tutuł:</translation>
+        <translation>Tytuł:</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="81"/>
@@ -213,7 +213,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="915"/>
         <source>Greek</source>
-        <translation>Grecki</translation>
+        <translation>grecki</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="269"/>
@@ -228,7 +228,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="275"/>
         <source>Ctrl+Return</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+Enter</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="297"/>
@@ -268,7 +268,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="386"/>
         <source>Ask smart (ideal for practising)</source>
-        <translation>Pytaj inteligentnie (idealne do</translation>
+        <translation>Pytaj inteligentnie (idealny tryb ćwiczenia)</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="396"/>
@@ -288,12 +288,12 @@
     <message>
         <location filename="ui/openteacher.ui" line="417"/>
         <source>Random</source>
-        <translation type="unfinished"></translation>
+        <translation>Losowa</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="422"/>
         <source>Normal</source>
-        <translation type="unfinished"></translation>
+        <translation>Normalna</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="427"/>
@@ -333,7 +333,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="508"/>
         <source>Word:</source>
-        <translation>Słowo</translation>
+        <translation>Słowo:</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="564"/>
@@ -373,12 +373,12 @@
     <message>
         <location filename="ui/openteacher.ui" line="644"/>
         <source>Click here to view the answer of the current showed question.</source>
-        <translation>Kliknij tutaj aby zobaczyć odpowiedź na obecnie wyświetlane pytanie</translation>
+        <translation>Kliknij tutaj aby zobaczyć odpowiedź na obecnie wyświetlane pytanie.</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="647"/>
         <source>View answer</source>
-        <translation>Zobacz odpowiedź</translation>
+        <translation>Pokaż odpowiedź</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="660"/>
@@ -388,7 +388,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="663"/>
         <source>I was right</source>
-        <translation>Miałem rację</translation>
+        <translation>Miałem(-am) rację</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="670"/>
@@ -398,7 +398,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="673"/>
         <source>I was wrong</source>
-        <translation>Myliłem się</translation>
+        <translation>Myliłem(-am) się</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="681"/>
@@ -679,197 +679,197 @@
 <context>
     <name>OpenTeacher</name>
     <message>
-        <location filename="src/openteacher.py" line="207"/>
+        <location filename="src/openteacher.py" line="220"/>
         <source>Code</source>
         <translation>Kod</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="212"/>
+        <location filename="src/openteacher.py" line="225"/>
         <source>Localisation</source>
         <translation>Lokalizacja</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="306"/>
+        <location filename="src/openteacher.py" line="319"/>
         <source>License</source>
         <translation>Licencja</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1233"/>
+        <location filename="src/openteacher.py" line="1250"/>
         <source>No selection was detected.</source>
         <translation>Nie wykryto zaznaczenia.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1507"/>
+        <location filename="src/openteacher.py" line="1530"/>
         <source>Correct answer</source>
         <translation>Poprawna odpowiedź</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1593"/>
+        <location filename="src/openteacher.py" line="1625"/>
         <source>Translation: </source>
         <translation>Tłumaczenie:</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1602"/>
+        <location filename="src/openteacher.py" line="1634"/>
         <source>Think about the answer, and press the &apos;View answer&apos; button when you&apos;re done.</source>
         <translation>Przemyśl odpowiedź i naciśnij przycisk &apos;Zobacz odpowiedź&apos; kiedy będziesz gotowy.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1677"/>
+        <location filename="src/openteacher.py" line="1733"/>
         <source>Hint:</source>
         <translation>Podpowiedź:</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1670"/>
+        <location filename="src/openteacher.py" line="1726"/>
         <source>Click the button to start.</source>
         <translation>Naciśnij przycisk aby rozpocząć.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1732"/>
+        <location filename="src/openteacher.py" line="1788"/>
         <source>Test completed!</source>
         <translation>Test ukończony.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1732"/>
+        <location filename="src/openteacher.py" line="1788"/>
         <source>Test completed! Your note:</source>
         <translation>Test ukończony! Twoja ocena:</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1884"/>
+        <location filename="src/openteacher.py" line="1940"/>
         <source>Message</source>
         <translation>Wiadomość</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1884"/>
+        <location filename="src/openteacher.py" line="1940"/>
         <source>Do you want to save changes?</source>
         <translation>Czy chcesz zapisać zmiany?</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1904"/>
+        <location filename="src/openteacher.py" line="1960"/>
         <source>Exit lesson</source>
         <translation>Wyjdź z lekcji</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1904"/>
+        <location filename="src/openteacher.py" line="1960"/>
         <source>Are you sure you want to stop the lesson?</source>
         <translation>Czy na pewno chcesz przerwać lekcję?</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1948"/>
+        <location filename="src/openteacher.py" line="2004"/>
         <source>Supported</source>
         <translation>Wspierane</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2027"/>
+        <location filename="src/openteacher.py" line="2083"/>
         <source>Plain text</source>
         <translation>Czysty tekst</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2042"/>
+        <location filename="src/openteacher.py" line="2098"/>
         <source>Save...</source>
         <translation>Zapisz...</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2184"/>
+        <location filename="src/openteacher.py" line="2240"/>
         <source>Print Document</source>
         <translation>Drukuj dokument</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2236"/>
+        <location filename="src/openteacher.py" line="2292"/>
         <source>Error</source>
         <translation>Błąd</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="254"/>
+        <location filename="src/openteacher.py" line="267"/>
         <source>OpenTeacher authors</source>
         <translation>Twórcy programu OpenTeacher</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1194"/>
+        <location filename="src/openteacher.py" line="1211"/>
         <source>The word(s) were entered successfully.</source>
         <translation>Słowo(a) zostało(y) wprowadzone pomyślnie.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1230"/>
+        <location filename="src/openteacher.py" line="1247"/>
         <source>The word(s) were removed successfully.</source>
         <translation>Słowo(a) zostało(y) pomyślnie usunięte.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1832"/>
+        <location filename="src/openteacher.py" line="1888"/>
         <source>The wordlist from WRTS was imported successfully.</source>
         <translation>Lista słow została pomyślnie zaimportowana z WRTS.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1862"/>
+        <location filename="src/openteacher.py" line="1918"/>
         <source>Export successful</source>
         <translation>Eksport zakończony sukcesem</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1863"/>
+        <location filename="src/openteacher.py" line="1919"/>
         <source>Word list exported to WRTS.</source>
         <translation>Lista słów została wyeksportowana do WRTS.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1938"/>
+        <location filename="src/openteacher.py" line="1994"/>
         <source>New file created.</source>
         <translation>Utworzono nowy plik.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1966"/>
+        <location filename="src/openteacher.py" line="2022"/>
         <source>The selected file was opened successfully.</source>
         <translation>Wybrany plik został pomyślnie otworzony.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2109"/>
+        <location filename="src/openteacher.py" line="2165"/>
         <source>File saved.</source>
         <translation>Plik został zapisany.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2190"/>
+        <location filename="src/openteacher.py" line="2246"/>
         <source>The file was printed successfully.</source>
         <translation>Plik został pomyślnie wydrukowany.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="254"/>
+        <location filename="src/openteacher.py" line="267"/>
         <source>Project website</source>
         <translation>Strona projektu</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="251"/>
+        <location filename="src/openteacher.py" line="264"/>
         <source>OpenTeacher helps you learn a foreign language vocabulary.</source>
-        <translation type="unfinished"></translation>
+        <translation>OpenTeacher pomaga w nauce słownictwa w obcym języku.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>een = one</source>
         <translation>een = jeden</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>twee = two</source>
         <translation>twee = dwa</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>drie = three</source>
         <translation>drie = trzy</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>Warning</source>
         <translation>Ostrzeżenie</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>This credentials are saved in plain text on your harddrive.</source>
-        <translation type="unfinished"></translation>
+        <translation>Te dane uwierzytelniające są przechowywane w pliku tekstowym na dysku użytkownika.</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>Don&apos;t use this function on a public computer!</source>
         <translation>Nie używaj tej funkcji na publicznym komputerze!</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1948"/>
+        <location filename="src/openteacher.py" line="2004"/>
         <source>Open...</source>
         <translation>Otwórz...</translation>
     </message>
@@ -885,95 +885,95 @@
 <context>
     <name>QDialogButtonBox</name>
     <message>
-        <location filename="src/openteacher.py" line="188"/>
+        <location filename="src/openteacher.py" line="201"/>
         <source>Close without Saving</source>
         <translation>Zamknij bez zapisywania</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="175"/>
+        <location filename="src/openteacher.py" line="188"/>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="177"/>
+        <location filename="src/openteacher.py" line="190"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Anuluj</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="183"/>
+        <location filename="src/openteacher.py" line="196"/>
         <source>&amp;Save</source>
         <translation>&amp;Zapisz</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="179"/>
+        <location filename="src/openteacher.py" line="192"/>
         <source>&amp;Yes</source>
         <translation>&amp;Tak</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="180"/>
+        <location filename="src/openteacher.py" line="193"/>
         <source>&amp;No</source>
         <translation>&amp;Nie</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="174"/>
+        <location filename="src/openteacher.py" line="187"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="176"/>
+        <location filename="src/openteacher.py" line="189"/>
         <source>Cancel</source>
         <translation>Anuluj</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="182"/>
+        <location filename="src/openteacher.py" line="195"/>
         <source>Save</source>
         <translation>Zapisz</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="184"/>
+        <location filename="src/openteacher.py" line="197"/>
         <source>Open</source>
         <translation>Otwórz</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="185"/>
+        <location filename="src/openteacher.py" line="198"/>
         <source>Close</source>
         <translation>Zamknij</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="186"/>
+        <location filename="src/openteacher.py" line="199"/>
         <source>&amp;Close</source>
         <translation>&amp;Zamknij</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="189"/>
+        <location filename="src/openteacher.py" line="202"/>
         <source>Don&apos;t save</source>
         <translation>Nie zapisuj</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="190"/>
+        <location filename="src/openteacher.py" line="203"/>
         <source>Discard</source>
-        <translation>Porzuć</translation>
+        <translation>Odrzuć</translation>
     </message>
 </context>
 <context>
     <name>QShortcut</name>
     <message>
-        <location filename="src/openteacher.py" line="193"/>
+        <location filename="src/openteacher.py" line="206"/>
         <source>Ctrl</source>
         <translation>Ctrl</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="194"/>
+        <location filename="src/openteacher.py" line="207"/>
         <source>Return</source>
         <translation>Powrót</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="195"/>
+        <location filename="src/openteacher.py" line="208"/>
         <source>Del</source>
-        <translation type="unfinished">Del</translation>
+        <translation>Usuń</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="196"/>
+        <location filename="src/openteacher.py" line="209"/>
         <source>Shift</source>
         <translation>Shift</translation>
     </message>
@@ -983,76 +983,76 @@
     <message>
         <location filename="src/errors.py" line="71"/>
         <source>Could not save file. Please check that the filename is correct and that you have permission to write to the save location.</source>
-        <translation>Nie można zapisać pliku. Proszę się upewnić czy nazwa pliku jest poprawna oraz czy posiadasz prawa zapisu w wybranej lokalizacji.</translation>
+        <translation>Nie można zachować pliku. Upewnij się, że nazwa pliku jest poprawna i że posiadasz prawa do zapisu w wybranej lokalizacji.</translation>
     </message>
 </context>
 <context>
     <name>Settings</name>
     <message>
-        <location filename="src/openteacher.py" line="513"/>
+        <location filename="src/openteacher.py" line="526"/>
         <source>Restart please</source>
-        <translation>Proszę uruchomić ponownie program</translation>
+        <translation>Proszę ponownie uruchomić program</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="484"/>
+        <location filename="src/openteacher.py" line="497"/>
         <source>Connection to WRTS failed</source>
-        <translation>Błąd połączenia do WRTS</translation>
+        <translation>Błąd połączenia z WRTS</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="487"/>
+        <location filename="src/openteacher.py" line="500"/>
         <source>Connection to WRTS succeeded</source>
         <translation>Pomyślnie połączono z WRTS</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="513"/>
+        <location filename="src/openteacher.py" line="526"/>
         <source>You changed the language. In order to use the newly selected language, you need to restart OpenTeacher.</source>
-        <translation>Zmieniono język. Aby używać nowo wybranego języka musisz zrestartować program OpenTeacher.</translation>
+        <translation>Zmieniono język. Aby używać wybranego języka musisz zrestartować program OpenTeacher.</translation>
     </message>
 </context>
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="src/openteacher.py" line="398"/>
+        <location filename="src/openteacher.py" line="411"/>
         <source>Make your choice</source>
         <translation>Dokonaj wyboru</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="399"/>
+        <location filename="src/openteacher.py" line="412"/>
         <source>System default</source>
         <translation>Domyślny systemu</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="447"/>
+        <location filename="src/openteacher.py" line="460"/>
         <source>Make your choice (all examples are good to bad)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="448"/>
+        <location filename="src/openteacher.py" line="461"/>
         <source>Percents</source>
         <translation>Procenty</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="449"/>
+        <location filename="src/openteacher.py" line="462"/>
         <source>Dutch</source>
-        <translation type="unfinished"></translation>
+        <translation>niderlandzki</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="450"/>
+        <location filename="src/openteacher.py" line="463"/>
         <source>American</source>
         <translation>Amerykański</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="451"/>
+        <location filename="src/openteacher.py" line="464"/>
         <source>German</source>
-        <translation>Niemiecki</translation>
+        <translation>niemiecki</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="452"/>
+        <location filename="src/openteacher.py" line="465"/>
         <source>French</source>
-        <translation>Francuski</translation>
+        <translation>francuski</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="453"/>
+        <location filename="src/openteacher.py" line="466"/>
         <source>ECTS</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1070,28 +1070,28 @@
     <message>
         <location filename="src/errors.py" line="47"/>
         <source>File couldn&apos;t be opened. Unsupported extension.</source>
-        <translation>Plik nie może zostać otworzony. Nieobsługiwane rozszerzenie.</translation>
+        <translation>Nie można otworzyć pliku. Nie rozpoznano rozszerzenia.</translation>
     </message>
 </context>
 <context>
     <name>WordListTableModel</name>
     <message>
-        <location filename="src/openteacher.py" line="648"/>
+        <location filename="src/openteacher.py" line="661"/>
         <source>Question</source>
-        <translation>Pyatnie</translation>
+        <translation>Pytanie</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="649"/>
+        <location filename="src/openteacher.py" line="662"/>
         <source>Answer</source>
         <translation>Odpowiedź</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="650"/>
+        <location filename="src/openteacher.py" line="663"/>
         <source>Second Answer (optional)</source>
         <translation>Druga odpowiedź (opcjonalne)</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="651"/>
+        <location filename="src/openteacher.py" line="664"/>
         <source>Errors</source>
         <translation>Błędy</translation>
     </message>
@@ -1109,7 +1109,7 @@
     <message>
         <location filename="src/errors.py" line="39"/>
         <source>WRTS didn&apos;t accept the login credentials. Are you sure you entered your e-mail and password correctly?</source>
-        <translation type="unfinished"></translation>
+        <translation>Logowanie do WRTS nie powiodło się. Sprawdź, czy wprowadzone dane (e-mail i hasło) są poprawne.</translation>
     </message>
 </context>
 </TS>
