@@ -18,7 +18,7 @@
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #Version, used at the moment in the about dialog
-__version__ = "2.2.1"
+__version__ = "2.3"
 
 #This are the contributors shown in the AboutDialog. Add your name if you contributed
 #to on OpenTeacher.
@@ -29,35 +29,38 @@ CODE_CONTRIBUTORS = (
 )
 
 TRANSLATION_CONTRIBUTORS = (
-	u"Thomas Berends, Guus, Ivo, Marten de Vries, Rachid (nl)",
-	u"Peter Widdershoven, Achmed Decker, HarzG (de)",
-	u"Startlett, Wolfgang Schweer, zerwas (de)",
-	u"Nelson Álvarez Sáez, Iván (es)",
-	u"kilo aka Gabor Kmetyko, Gabor Kelemen, blaselinux (hu)",
-	u"Pasha.P.Komar, Ruiz Aw, Skai Falkorr (ru)",
-	u"Ilhan Polat, Tolga, kosti (tr)",
-	u"Abdelmonam Kouka, Ahmed Osama, Ahmed Sghaier, Ahmed Shams (ar)",
-	u"Ahmed Toulan, El Achèche ANIS, Islam Wazery, Mohamed El Sharnoby (ar)",
-	u"TheNightPhoenix, computeristgeek, islamHassan (ar)",
-	u"Cromag (da)",
-	u"Jared Norris, Joel Pickett (en_AU)",
-	u"Ash, BriceF, Cyril Lavier, Guus, RedGuff (fr)",
-	u"Dooitze de Jong (fy)",
-	u"Omer Omer (he)",
-	u"Saša Teković, Tomislav Marčinković (hr)",
-	u"Prayudi Satriyo N (id)",
-	u"Gianluca Piana, enrico di paolantonio (it)",
-	u"Emmanuel Chanel (ja)",
-	u"jincreator (ko)",
-	u"Jo-Erlend Schinstad (nb)",
-	u"Vorbis^, soee (pl)",
-	u"Mojca Ograjšek, Andrej Znidarsic (sl)",
-	u"Мирослав Николић (sr)",
-	u"Daniel Nylander, Martin Lundberg (sv)",
-	u"jack (zh_CN)",
-	u"Louie Chen (zh_TW)",
-	u"Cédric VALMARY (oc)",
-	u"Ciprian Panaite (ro)",
+	u"Australian English: Jared Norris, Joel Pickett",
+	u"Bahasa Indonesia: Prayudi Satriyo N",
+	u"Dansk: Aputsiaq Niels Janussen, Cromag",
+	u"Deutsch: Achmed Decker, Dennis Baudys, HarzG, Peter Widdershoven,\nStartlett, Tim O., Wolfgang Schweer, ubuntuuser87, zerwas",
+	u"Español: Adolfo Jayme Barrientos, Iván, Morgus, Nelson Álvarez Sáez",
+	u"Français: Achraf FOUWAD, BriceF, Cyril Lavier, Guus, Léo POUGHON,\nRedGuff",
+	u"Frysk: Dooitze de Jong",
+	u"Galego: xesusmosquera",
+	u"Hrvatski: Saša Teković, Tomislav Marčinković",
+	u"Italiano: Gianluca Piana, Guybrush88, enrico di paolantonio",
+	u"Magyar: Gabor Kelemen, Papp Bence, Richard Somlói, blaselinux,\nkilo aka Gabor Kmetyko",
+	u"Nederlands: Guus, Ivo, Marten de Vries, Rachid",
+	u"Norsk bokmål: Jo-Erlend Schinstad, Mathias Bynke",
+	u"Occitan: Cédric VALMARY (Tot en òc)",
+	u"Polski: Magdalena Gazda, Vorbis^, soee",
+	u"Português brasileiro: Otto Robba",
+	u"Română: Ciprian Panaite",
+	u"Slovenščina: Andrej Znidarsic, Mojca Ograjšek",
+	u"Svenska: Daniel Nylander, Jonas Zetterholm, Martin Lundberg",
+	u"Türkçe: Tolga, kosti",
+	u"Valencià: Xangel",
+	u"čeština: Jakub Šnapka, Jan Havran",
+	u"Ўзбек тили: Akmal Xushvaqov",
+	u"Русский: Pasha.P.Komar, Ruiz Aw, Skai Falkorr, Vyacheslav Sharmanov",
+	u"Українська мова: Alex Krynko",
+	u"српски језик: Мирослав Николић",
+	u"עברית: Omer Omer",
+	u"العربية: Abdelmonam Kouka, Ahmed Osama, Ahmed Sghaier, Ahmed Shams,\nAhmed Toulan, El Achèche ANIS, Islam Hassan, Islam Wazery,\nMohamed El Sharnoby, TheNightPhoenix, computeristgeek",
+	u"日本語: Emmanuel Chanel",
+	u"正體字: BlueT - Matthew Lien - 練喆明, Louie Chen",
+	u"简化字: Xu Bin, ZhangCheng, jack",
+	u"한국어: Jinkyu Yi",
 )
 
 #This are the characters shown in the enter_table if the user didn't change them.
@@ -69,7 +72,8 @@ TABLE_CHARS = (
 	(u"ì", u"ì", u"î", u"ï", u"Û", u"û"),
 	(u"Ì", u"Í", u"Î", u"Ï", u"Ú", u"ú"),
 	(u"ò", u"ó", u"ô", u"ö", u"Ü", u"ü"),
-	(u"Ò", u"Ó", u"Ô", u"Ö", u"Ù", u"ß")
+	(u"Ò", u"Ó", u"Ô", u"Ö", u"Ù", u"ß"),
+	(u"\,", u"\;", u"\=", u"", u"", u""),
 )
 
 #The same for the greek chars. The difference is they're hardcoded.
@@ -128,6 +132,12 @@ LANGUAGES = {
 	u"zh_TW": u"正體字",
 	u"ro": u"Română",
 	u"oc": u"Occitan",
+	u"pt_BR": u"Português brasileiro",
+	u"uz": u"Ўзбек тили",
+	u"ca@valencia": u"Valencià",
+	u"uk": u"Українська мова",
+	u"cs": u"čeština",
+	u"gl": u"Galego",
 }
 
 DEFAULT_FADE_DURATION_WHEN_WRONG = 2000
@@ -169,6 +179,7 @@ import difflib
 import math
 import os
 import random
+import re
 
 #We only translate the Qt-classes we need
 
@@ -692,7 +703,8 @@ class WordListTableModel(QtCore.QAbstractTableModel):
 
 	def setData(self, index, value, role):
 		"""Same as data(), but now it sets data instead of returning it."""
-		value = value.toString()
+		#do the strip() here already so an empty string never can become the result.
+		value = unicode(value.toString()).strip()
 		if index.isValid() and role == QtCore.Qt.EditRole:
 			column = index.column()
 			if column == 0:
@@ -870,11 +882,13 @@ class OpenTeacher(QtGui.QMainWindow):
 		QtGui.QWidget.__init__(self, parent)
 		self.ui = gui.openteacher.Ui_MainWindow()
 		self.ui.setupUi(self)
-		self.splitters= {} #FIXME
-#		self.splitters = {"wordlistAndEnter_splitter": self.ui.wordlistAndEnter_splitter,
-#						  "charAndInput_splitter": self.ui.charAndInput_splitter,
-#						  "metadataAndInput_splitter": self.ui.metadataAndInput_splitter,
-#						  "charAndTeach_splitter": self.ui.charAndTeach_splitter}
+		self.splitters = {
+			"wordlistAndEnter_splitter": self.ui.wordlistAndEnter_splitter,
+			"charAndInput_splitter": self.ui.charAndInput_splitter,
+			"metadataAndInput_splitter": self.ui.metadataAndInput_splitter,
+			"teachSplitter": self.ui.teachSplitter,
+			"innerTeachSplitter": self.ui.innerTeachSplitter,
+		}
 
 		#Set the current filename to nothing, needed for the try of opening a file after this.
 		self.saveFilename = unicode()
@@ -994,6 +1008,11 @@ class OpenTeacher(QtGui.QMainWindow):
 			splitter = self.splitters[splitter_name]
 			splitter.restoreState(self.settings.value(splitter_name).toByteArray())
 
+		#resize word list view header
+		self.ui.wordsTable.horizontalHeader().resizeSections(
+			QtGui.QHeaderView.ResizeToContents
+		)
+
 		#Create a connection to WRTS; not useable until the user logged in.
 		self.wrtsConnection = api.wrts.WrtsConnection()
 
@@ -1114,6 +1133,7 @@ class OpenTeacher(QtGui.QMainWindow):
 
 	def enter(self):
 		"""Method to enter the words from the enterTextField into the wordsTable"""
+
 		#No line without equals sign passed yet.
 		withoutEqualsSign = False
 		#Get the user input from the GUI
@@ -1127,16 +1147,12 @@ class OpenTeacher(QtGui.QMainWindow):
 		lines = userInput.split('\n')
 		#Run over the input line by line.
 		for line in lines[:]:
-			if "=" in line:
-				#Check for equals-sign; if there is one split the question from the answer
-				splittedLine = line.split("=", 1)
-			elif "\t" in line:
-				#Check for tab; if there is one split the question from the answer
-				splittedLine = line.split("\t", 1)
-			elif line.strip() == "":
-				#If the line is blank, just go to the next one.
+			if line.strip() == "":
 				continue
-			else:
+			try:
+				#try to split question and answer(s)
+				question, answers = re.split(r"(?<!\\)[=\t]", line, maxsplit=1)
+			except IndexError:
 				#Input doesn't have a equals-sign or a tab. Set the GUI
 				#to unsaved, and put the unprocessed lines back into the
 				#textEdit. Then inform the user.
@@ -1148,45 +1164,44 @@ class OpenTeacher(QtGui.QMainWindow):
 
 				self.showError(errors.NoEqualsSignInInputError())
 				return
-			
-			#Check if the input is valid (not '=,', '= =' or something like that.)
-			if len(splittedLine) == 2 and splittedLine[0] != "" and splittedLine[1] != "":
-				#Instantiate a word and set the question
-				word = words.Word()
-				word.question = splittedLine[0]
-				#Get the answer/the multiple answers
-				answerLine = splittedLine[1]
-				#Check if there is a second answer (separated by , or ;)
-				if ";" in answerLine:
-					#Splits only at the first ';', others are left intact in the second answer.
-					splittedAnswer = answerLine.split(";", 1)
-				elif "," in answerLine:
-					#See ';'
-					splittedAnswer = answerLine.split(",", 1)
 
-				#Check if a second answer was found
-				try:
-					splittedAnswer
-				except NameError:
-					#one answer, just use the full answerLine as answer.
-					word.answer = answerLine
-				else:
-					#two answers, get them from the splitted answer.
-					word.answer = splittedAnswer[0]
-					word.secondAnswer = splittedAnswer[1]
-					#Remove splittedAnswer, so it's not used anywhere further in the loop.
-					del splittedAnswer
-
-				#Add the word to the wordListTable, which also is at the moment the masterwordlist.
-				self.wordListTableModel.addWord(word)
-				
-				#Remove the processed line
-				del lines[0]
-			else:
+			question = question.strip()
+			answers = answers.strip()
+			if question == "" or answers == "":
 				#Wrong formatted input (and not a problem with the equals sign/tab)
 				self.showError(errors.InputFormatError())
+
+				#Input doesn't have a equals-sign or a tab. Set the GUI
+				#to unsaved, and put the unprocessed lines back into the
+				#textEdit. Then inform the user.
+				text = u"\n".join(lines)
+				self.ui.enterTextField.setText(text)
+
+				self.setUnsaved()
+				self.checkEmpty()
+
 				return
 
+			#split answers
+			answers = re.split(r"(?<!\\)[,;]", answers, maxsplit=1)
+			#strip them
+			answers = map(lambda a: a.strip(), answers)
+			#and remove the empty ones
+			answers = filter(lambda a: a != "", answers)
+
+			#Instantiate a word and set the data
+			word = words.Word()
+			word.question = question
+
+			word.answer = answers[0]
+			if len(answers) == 2:
+				word.secondAnswer = answers[1]
+			#Add the word to the wordListTable, which also is at the moment the masterwordlist.
+			self.wordListTableModel.addWord(word)
+				
+			#Remove the processed line
+			del lines[0]
+
 		#Everything went fine, clear the enterTextField and set the GUI to unsaved.
 		self.ui.enterTextField.clear()
 		self.setUnsaved()
@@ -1471,11 +1486,17 @@ class OpenTeacher(QtGui.QMainWindow):
 			userInput = self.ui.transEditRepeat
 			correctLabel = self.ui.correctLabelRepeat
 
-		#Check the input with the first answer
-		if userInput.text() == self.currentWord.answer:
+		answers = re.split(r"(?<!\\)[,;]", unicode(userInput.text()), maxsplit=1)
+		answers = map(lambda a: a.strip(), answers)
+
+		#One answer, the first one.
+		if len(answers) == 1 and answers[0] == self.currentWord.answer:
 			self.answerRight()
-		#Check the input with the second answer if there is one
-		elif self.currentWord.secondAnswerSet() and userInput.text() == self.currentWord.secondAnswer:
+		#One answer, the second one.
+		elif len(answers) == 1 and self.currentWord.secondAnswerSet() and answers[0] == self.currentWord.secondAnswer:
+			self.answerRight()
+		#Two answers, both are given.
+		elif len(answers) == 2 and self.currentWord.secondAnswerSet() and self.currentWord.answer in answers and self.currentWord.secondAnswer in answers:
 			self.answerRight()
 		#Wrong answer
 		else:
@@ -1545,6 +1566,15 @@ class OpenTeacher(QtGui.QMainWindow):
 			self.ui.correctButtonRepeat.setEnabled(False)
 			#Update the score in the GUI
 			self.updateScore()
+		
+		#Check typing mode to check, and set associated vars
+		if self.LessonMode.TYPING == self.ui.questionType.currentIndex():
+			userInput = self.ui.transEdit
+		elif self.LessonMode.SHUFFLE == self.ui.questionType.currentIndex():
+			userInput = self.ui.transEditShuffle
+		elif self.LessonMode.REPEAT == self.ui.questionType.currentIndex():
+			userInput = self.ui.transEditRepeat
+		userInput.setFocus()
 
 	def answerRight(self):
 		"""Sets the answer to right, called by program or user when in 'in mind'-mode"""
@@ -2246,7 +2276,7 @@ class OpenTeacher(QtGui.QMainWindow):
 				lang = unicode(self.settings.value("language").toString())
 
 		docDialog = DocumentationDialog(lang, self)
-		docDialog.exec_()
+		docDialog.show()
 
 	def setupDesignedDialog(self, designedDialogClass):
 		"""Method which does setup a dialog created by Qt Designer, and returns it to the user. All left is calling exec_()"""
