@@ -1,11 +1,11 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS><TS version="2.0">
 <context>
     <name>AbortedByUserError</name>
     <message>
         <location filename="src/errors.py" line="43"/>
         <source>The user aborted the current action.</source>
-        <translation type="unfinished"></translation>
+        <translation>用户放弃当前动作。</translation>
     </message>
 </context>
 <context>
@@ -13,7 +13,7 @@
     <message>
         <location filename="src/errors.py" line="55"/>
         <source>Could not open file because its contents are invalid, or written in a way not supported by OpenTeacher.</source>
-        <translation type="unfinished"></translation>
+        <translation>文件无法打开，因为内容不正确，或写入格式不被OpenTeacher支持。</translation>
     </message>
 </context>
 <context>
@@ -36,7 +36,7 @@
     <message>
         <location filename="ui/about.ui" line="169"/>
         <source>Full license text</source>
-        <translation type="unfinished"></translation>
+        <translation>授权文件全文</translation>
     </message>
     <message>
         <location filename="ui/about.ui" line="195"/>
@@ -51,7 +51,7 @@
     <message>
         <location filename="ui/wrtsLogin.ui" line="13"/>
         <source>WRTS - login please:</source>
-        <translation type="unfinished"></translation>
+        <translation>WRTS 登录</translation>
     </message>
     <message>
         <location filename="ui/wrtsLogin.ui" line="22"/>
@@ -66,7 +66,7 @@
     <message>
         <location filename="ui/settings.ui" line="14"/>
         <source>OpenTeacher - Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>OpenTeacher - 设置</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="24"/>
@@ -81,32 +81,32 @@
     <message>
         <location filename="ui/settings.ui" line="44"/>
         <source>Show &apos;overwrite&apos;-dialogs</source>
-        <translation type="unfinished"></translation>
+        <translation>显示 &apos;覆写&apos;-对话框</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="57"/>
         <source>Show &apos;do you want to save&apos;-dialogs</source>
-        <translation type="unfinished"></translation>
+        <translation>显示 &apos;您是否希望保存&apos;-对话框</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="70"/>
         <source>Lesson</source>
-        <translation type="unfinished"></translation>
+        <translation>课程</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="76"/>
         <source>Show &apos;stop lesson&apos;-dialogs</source>
-        <translation type="unfinished"></translation>
+        <translation>显示 &apos;停止课程&apos;-对话框</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="86"/>
         <source>Show &apos;lesson completed&apos;-dialogs</source>
-        <translation type="unfinished"></translation>
+        <translation>显示 &apos;课程完成&apos;-对话框</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="98"/>
         <source>Fade duration when wrong:</source>
-        <translation type="unfinished"></translation>
+        <translation>错误时褪色</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="155"/>
@@ -116,17 +116,17 @@
     <message>
         <location filename="ui/settings.ui" line="133"/>
         <source>Repeat mode hint duration:</source>
-        <translation type="unfinished"></translation>
+        <translation>重复模式的提示间隔：</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="168"/>
         <source>Note notation:</source>
-        <translation type="unfinished"></translation>
+        <translation>注解标志</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="183"/>
         <source>WRTS</source>
-        <translation type="unfinished"></translation>
+        <translation>WRTS</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="189"/>
@@ -136,17 +136,17 @@
     <message>
         <location filename="ui/settings.ui" line="213"/>
         <source>Try to connect to WRTS</source>
-        <translation type="unfinished"></translation>
+        <translation>尝试连接到 ERTS</translation>
     </message>
     <message>
         <location filename="ui/about.ui" line="216"/>
         <source>Thanks to all Launchpad contributors!</source>
-        <translation type="unfinished"></translation>
+        <translation>感谢所有为Launchpad 做出贡献的人!</translation>
     </message>
     <message>
         <location filename="ui/wrtsListChoice.ui" line="14"/>
         <source>Choose WRTS list:</source>
-        <translation type="unfinished"></translation>
+        <translation>选择 WRTS 列表:</translation>
     </message>
     <message>
         <location filename="ui/settings.ui" line="230"/>
@@ -157,7 +157,7 @@
 <context>
     <name>DocumentationDialog</name>
     <message>
-        <location filename="src/openteacher.py" line="343"/>
+        <location filename="src/openteacher.py" line="356"/>
         <source>Documentation</source>
         <translation>文档</translation>
     </message>
@@ -167,7 +167,7 @@
     <message>
         <location filename="src/errors.py" line="59"/>
         <source>There seems to be no content in the input area</source>
-        <translation type="unfinished"></translation>
+        <translation>输入区域中似乎没有内容</translation>
     </message>
 </context>
 <context>
@@ -175,7 +175,7 @@
     <message>
         <location filename="src/errors.py" line="63"/>
         <source>There seems to be something wrong with the default input formatting (question = answer)</source>
-        <translation type="unfinished"></translation>
+        <translation>使用默认输入格式出错(问题 = 回答)</translation>
     </message>
 </context>
 <context>
@@ -183,12 +183,12 @@
     <message>
         <location filename="ui/openteacher.ui" line="14"/>
         <source>OpenTeacher</source>
-        <translation type="unfinished"></translation>
+        <translation>OpenTeacher</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="38"/>
         <source>Enter list</source>
-        <translation type="unfinished"></translation>
+        <translation>输入列表</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="68"/>
@@ -198,12 +198,12 @@
     <message>
         <location filename="ui/openteacher.ui" line="81"/>
         <source>Question Language:</source>
-        <translation type="unfinished"></translation>
+        <translation>提问语言:</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="94"/>
         <source>Answer Language:</source>
-        <translation type="unfinished"></translation>
+        <translation>回答语言:</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="874"/>
@@ -223,22 +223,22 @@
     <message>
         <location filename="ui/openteacher.ui" line="272"/>
         <source>Enter!</source>
-        <translation type="unfinished"></translation>
+        <translation>进入！</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="275"/>
         <source>Ctrl+Return</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+回车</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="297"/>
         <source>Remove selected row(s)</source>
-        <translation type="unfinished"></translation>
+        <translation>移除选中的行</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="300"/>
         <source>Del</source>
-        <translation type="unfinished"></translation>
+        <translation>删除键</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="330"/>
@@ -248,7 +248,7 @@
     <message>
         <location filename="ui/openteacher.ui" line="357"/>
         <source>Question Order:</source>
-        <translation type="unfinished"></translation>
+        <translation>问题顺序：</translation>
     </message>
     <message>
         <location filename="ui/openteacher.ui" line="365"/>
@@ -679,197 +679,197 @@
 <context>
     <name>OpenTeacher</name>
     <message>
-        <location filename="src/openteacher.py" line="207"/>
+        <location filename="src/openteacher.py" line="220"/>
         <source>Code</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="212"/>
+        <location filename="src/openteacher.py" line="225"/>
         <source>Localisation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="306"/>
+        <location filename="src/openteacher.py" line="319"/>
         <source>License</source>
         <translation type="unfinished">授权</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1233"/>
+        <location filename="src/openteacher.py" line="1250"/>
         <source>No selection was detected.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1507"/>
+        <location filename="src/openteacher.py" line="1530"/>
         <source>Correct answer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1593"/>
+        <location filename="src/openteacher.py" line="1625"/>
         <source>Translation: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1602"/>
+        <location filename="src/openteacher.py" line="1634"/>
         <source>Think about the answer, and press the &apos;View answer&apos; button when you&apos;re done.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1677"/>
+        <location filename="src/openteacher.py" line="1733"/>
         <source>Hint:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1670"/>
+        <location filename="src/openteacher.py" line="1726"/>
         <source>Click the button to start.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1732"/>
+        <location filename="src/openteacher.py" line="1788"/>
         <source>Test completed!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1732"/>
+        <location filename="src/openteacher.py" line="1788"/>
         <source>Test completed! Your note:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1884"/>
+        <location filename="src/openteacher.py" line="1940"/>
         <source>Message</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1884"/>
+        <location filename="src/openteacher.py" line="1940"/>
         <source>Do you want to save changes?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1904"/>
+        <location filename="src/openteacher.py" line="1960"/>
         <source>Exit lesson</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1904"/>
+        <location filename="src/openteacher.py" line="1960"/>
         <source>Are you sure you want to stop the lesson?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1948"/>
+        <location filename="src/openteacher.py" line="2004"/>
         <source>Supported</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2027"/>
+        <location filename="src/openteacher.py" line="2083"/>
         <source>Plain text</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2042"/>
+        <location filename="src/openteacher.py" line="2098"/>
         <source>Save...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2184"/>
+        <location filename="src/openteacher.py" line="2240"/>
         <source>Print Document</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2236"/>
+        <location filename="src/openteacher.py" line="2292"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="254"/>
+        <location filename="src/openteacher.py" line="267"/>
         <source>OpenTeacher authors</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1194"/>
+        <location filename="src/openteacher.py" line="1211"/>
         <source>The word(s) were entered successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1230"/>
+        <location filename="src/openteacher.py" line="1247"/>
         <source>The word(s) were removed successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1832"/>
+        <location filename="src/openteacher.py" line="1888"/>
         <source>The wordlist from WRTS was imported successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1862"/>
+        <location filename="src/openteacher.py" line="1918"/>
         <source>Export successful</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1863"/>
+        <location filename="src/openteacher.py" line="1919"/>
         <source>Word list exported to WRTS.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1938"/>
+        <location filename="src/openteacher.py" line="1994"/>
         <source>New file created.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1966"/>
+        <location filename="src/openteacher.py" line="2022"/>
         <source>The selected file was opened successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2109"/>
+        <location filename="src/openteacher.py" line="2165"/>
         <source>File saved.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="2190"/>
+        <location filename="src/openteacher.py" line="2246"/>
         <source>The file was printed successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="254"/>
+        <location filename="src/openteacher.py" line="267"/>
         <source>Project website</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="251"/>
+        <location filename="src/openteacher.py" line="264"/>
         <source>OpenTeacher helps you learn a foreign language vocabulary.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>een = one</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>twee = two</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="980"/>
+        <location filename="src/openteacher.py" line="996"/>
         <source>drie = three</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>This credentials are saved in plain text on your harddrive.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="371"/>
+        <location filename="src/openteacher.py" line="384"/>
         <source>Don&apos;t use this function on a public computer!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="1948"/>
+        <location filename="src/openteacher.py" line="2004"/>
         <source>Open...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -885,72 +885,72 @@
 <context>
     <name>QDialogButtonBox</name>
     <message>
-        <location filename="src/openteacher.py" line="188"/>
+        <location filename="src/openteacher.py" line="201"/>
         <source>Close without Saving</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="175"/>
+        <location filename="src/openteacher.py" line="188"/>
         <source>&amp;OK</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="177"/>
+        <location filename="src/openteacher.py" line="190"/>
         <source>&amp;Cancel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="183"/>
+        <location filename="src/openteacher.py" line="196"/>
         <source>&amp;Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="179"/>
+        <location filename="src/openteacher.py" line="192"/>
         <source>&amp;Yes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="180"/>
+        <location filename="src/openteacher.py" line="193"/>
         <source>&amp;No</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="174"/>
+        <location filename="src/openteacher.py" line="187"/>
         <source>OK</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="176"/>
+        <location filename="src/openteacher.py" line="189"/>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="182"/>
+        <location filename="src/openteacher.py" line="195"/>
         <source>Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="184"/>
+        <location filename="src/openteacher.py" line="197"/>
         <source>Open</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="185"/>
+        <location filename="src/openteacher.py" line="198"/>
         <source>Close</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="186"/>
+        <location filename="src/openteacher.py" line="199"/>
         <source>&amp;Close</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="189"/>
+        <location filename="src/openteacher.py" line="202"/>
         <source>Don&apos;t save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="190"/>
+        <location filename="src/openteacher.py" line="203"/>
         <source>Discard</source>
         <translation type="unfinished"></translation>
     </message>
@@ -958,22 +958,22 @@
 <context>
     <name>QShortcut</name>
     <message>
-        <location filename="src/openteacher.py" line="193"/>
+        <location filename="src/openteacher.py" line="206"/>
         <source>Ctrl</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="194"/>
+        <location filename="src/openteacher.py" line="207"/>
         <source>Return</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="195"/>
+        <location filename="src/openteacher.py" line="208"/>
         <source>Del</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">删除键</translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="196"/>
+        <location filename="src/openteacher.py" line="209"/>
         <source>Shift</source>
         <translation type="unfinished"></translation>
     </message>
@@ -989,22 +989,22 @@
 <context>
     <name>Settings</name>
     <message>
-        <location filename="src/openteacher.py" line="513"/>
+        <location filename="src/openteacher.py" line="526"/>
         <source>Restart please</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="484"/>
+        <location filename="src/openteacher.py" line="497"/>
         <source>Connection to WRTS failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="487"/>
+        <location filename="src/openteacher.py" line="500"/>
         <source>Connection to WRTS succeeded</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="513"/>
+        <location filename="src/openteacher.py" line="526"/>
         <source>You changed the language. In order to use the newly selected language, you need to restart OpenTeacher.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1012,47 +1012,47 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="src/openteacher.py" line="398"/>
+        <location filename="src/openteacher.py" line="411"/>
         <source>Make your choice</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="399"/>
+        <location filename="src/openteacher.py" line="412"/>
         <source>System default</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="447"/>
+        <location filename="src/openteacher.py" line="460"/>
         <source>Make your choice (all examples are good to bad)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="448"/>
+        <location filename="src/openteacher.py" line="461"/>
         <source>Percents</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="449"/>
+        <location filename="src/openteacher.py" line="462"/>
         <source>Dutch</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="450"/>
+        <location filename="src/openteacher.py" line="463"/>
         <source>American</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="451"/>
+        <location filename="src/openteacher.py" line="464"/>
         <source>German</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="452"/>
+        <location filename="src/openteacher.py" line="465"/>
         <source>French</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="453"/>
+        <location filename="src/openteacher.py" line="466"/>
         <source>ECTS</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1076,22 +1076,22 @@
 <context>
     <name>WordListTableModel</name>
     <message>
-        <location filename="src/openteacher.py" line="648"/>
+        <location filename="src/openteacher.py" line="661"/>
         <source>Question</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="649"/>
+        <location filename="src/openteacher.py" line="662"/>
         <source>Answer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="650"/>
+        <location filename="src/openteacher.py" line="663"/>
         <source>Second Answer (optional)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="src/openteacher.py" line="651"/>
+        <location filename="src/openteacher.py" line="664"/>
         <source>Errors</source>
         <translation type="unfinished"></translation>
     </message>
